<?php

class St_Brochure_Widget extends WP_Widget {
	function __construct() {
		$widget_ops = array( 'description' => __( 'Displays brochures for download.', 'adamas-custom-widgets' ) );
		parent::__construct( 'st_brochure_widget', __( 'Brochures', 'adamas-custom-widgets' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$max_entries = 3;
		$title       = $before_title . apply_filters( 'widget_title', $instance['title'] ) . $after_title;
		echo $before_widget;
		if ( ! empty( $instance['title'] ) ) {
			echo $title;
		}
		?>
        <div class="st-brochure-widget-inner">
			<?php
			for ( $i = 0; $i < $max_entries; $i ++ ) {
				$block = $instance[ 'block-' . $i ];
				if ( isset( $block ) && $block !== "" ) {
					// File
					$file_url     = esc_url( $instance[ 'file_uri-' . $i ] );
					$target       = $instance[ 'target_blank-' . $i ];
					$size         = $instance[ 'hide_size-' . $i ];
					$extension    = $instance[ 'hide_extension-' . $i ];
					$target_blank = isset( $target ) ? 'true' : 'false';
					if ( $target_blank === 'true' ) {
						$file = '<a href="' . $file_url . '" target="_blank">';
					} else {
						$file = '<a href="' . $file_url . '">';
					}
					$file_after     = '</a>';
					$hide_size      = isset( $size ) ? 'true' : 'false';
					$hide_extension = isset( $extension ) ? 'true' : 'false';
					$path_parts     = pathinfo( $file_url );
					$file_get       = wp_remote_get( $file_url );
					$size           = wp_remote_retrieve_header( $file_get, 'Content-Length' );

					$file_size = '';
					switch ( $size ) {
						case $size < 1024:
							$file_size = $size . ' B';
							break;
						case $size < 1048576:
							$file_size = round( $size / 1024, 2 ) . ' KB';
							break;
						case $size < 1073741824:
							$file_size = round( $size / 1048576, 2 ) . ' MB';
							break;
						case $size < 1099511627776:
							$file_size = round( $size / 1073741824, 2 ) . ' GB';
							break;
					}

					if ( $hide_size === 'true' ) {
						$file_size_output = '';
					} else {
						$file_size_output = esc_attr( $file_size );
					}

					if ( $hide_extension === 'true' ) {
						$extension_output = '';
					} else {
						$extension_output = strtoupper( $path_parts['extension'] );
					}

					?>

                    <div class="st-brochure-widget-item">
						<?php echo $file; ?>
						<?php if ( is_rtl() ) { ?>
                            <div class="st-brochure-widget-file-info <?php echo esc_attr( $path_parts['extension'] ); ?>"><?php echo $instance[ 'brochure_name-' . $i ]; ?>
								<?php
								if ( $extension_output !== '' || $file_size_output !== '' ) {
									if ( $extension_output !== '' ) {
										echo $extension_output;
									}
									if ( $extension_output !== '' && $file_size_output !== '' ) {
										echo ', ';
									}
									if ( $file_size_output !== '' ) {
										echo $file_size_output;
									}
								}
								?>
                            </div>
						<?php } else { ?>
                            <div class="st-brochure-widget-file-info <?php echo esc_attr( $path_parts['extension'] ); ?>"><?php echo esc_html( $instance[ 'brochure_name-' . $i ] ); ?>
								<?php
								if ( $extension_output !== '' || $file_size_output !== '' ) {
									echo ' (';
									if ( $extension_output !== '' ) {
										echo $extension_output;
									}
									if ( $extension_output !== '' && $file_size_output !== '' ) {
										echo ', ';
									}
									if ( $file_size_output !== '' ) {
										echo $file_size_output;
									}
									echo ')';
								}
								?>
                            </div>
						<?php } ?>
						<?php echo $file_after; ?>
                    </div>

				<?php }
			} ?>
        </div>
		<?php echo $after_widget; ?>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance          = array();
		$max_entries       = 3;
		$instance['title'] = strip_tags( $new_instance['title'] );
		for ( $i = 0; $i < $max_entries; $i ++ ) {
			$block = $new_instance[ 'block-' . $i ];
			if ( $block == 0 || $block == "" ) {
				$instance[ 'block-' . $i ]          = $new_instance[ 'block-' . $i ];
				$instance[ 'file_uri-' . $i ]       = $new_instance[ 'file_uri-' . $i ];
				$instance[ 'target_blank-' . $i ]   = $new_instance[ 'target_blank-' . $i ];
				$instance[ 'brochure_name-' . $i ]  = strip_tags( $new_instance[ 'brochure_name-' . $i ] );
				$instance[ 'hide_extension-' . $i ] = $new_instance[ 'hide_extension-' . $i ];
				$instance[ 'hide_size-' . $i ]      = $new_instance[ 'hide_size-' . $i ];
			} else {
				$count                              = $block - 1;
				$instance[ 'block-' . $count ]      = $new_instance[ 'block-' . $i ];
				$instance[ 'file_uri-' . $i ]       = $new_instance[ 'file_uri-' . $i ];
				$instance[ 'target_blank-' . $i ]   = $new_instance[ 'target_blank-' . $i ];
				$instance[ 'brochure_name-' . $i ]  = strip_tags( $new_instance[ 'brochure_name-' . $i ] );
				$instance[ 'hide_extension-' . $i ] = $new_instance[ 'hide_extension-' . $i ];
				$instance[ 'hide_size-' . $i ]      = $new_instance[ 'hide_size-' . $i ];
			}
		}

		return $instance;
	}

	function form( $instance ) {
		if ( ! isset( $instance['title'] ) ) {
			$instance['title'] = '';
		}
		$max_entries   = 3;
		$widget_add_id = $this->id . "-add";
		$title         = esc_attr( $instance['title'] );
		$output        = '<p>';
		$output        .= '<label for="' . esc_attr( $this->get_field_id( 'title' ) ) . '">' . esc_html__( 'Widget Title', 'adamas-custom-widgets' ) . ':</label>';
		$output        .= '<input id="' . esc_attr( $this->get_field_id( 'title' ) ) . '" name="' . esc_attr( $this->get_field_name( 'title' ) ) . '" type="text" value="' . esc_attr( $title ) . '" />';
		$output        .= '<div class="' . $widget_add_id . '-input-containers"><div id="entries">';
		for ( $i = 0; $i < $max_entries; $i ++ ) {
			$display = ( ! isset( $instance[ 'block-' . $i ] ) || ( $instance[ 'block-' . $i ] == "" ) ) ? 'style="display:none;"' : '';
			if ( $display ) {
				unset( $instance );
			}

			if ( ! isset( $instance[ 'block-' . $i ] ) ) {
				$instance[ 'block-' . $i ] = '';
			}
			if ( ! isset( $instance[ 'file_uri-' . $i ] ) ) {
				$instance[ 'file_uri-' . $i ] = '';
			}
			if ( ! isset( $instance[ 'target_blank-' . $i ] ) ) {
				$instance[ 'target_blank-' . $i ] = 'false';
			}
			if ( ! isset( $instance[ 'brochure_name-' . $i ] ) ) {
				$instance[ 'brochure_name-' . $i ] = '';
			}
			if ( ! isset( $instance[ 'hide_extension-' . $i ] ) ) {
				$instance[ 'hide_extension-' . $i ] = 'false';
			}
			if ( ! isset( $instance[ 'hide_size-' . $i ] ) ) {
				$instance[ 'hide_size-' . $i ] = 'false';
			}

			$block         = $instance[ 'block-' . $i ];
			$file_uri      = $instance[ 'file_uri-' . $i ];
			$brochure_name = $instance[ 'brochure_name-' . $i ];

			$output .= '<div id="entry' . ( $i + 1 ) . '" ' . $display . ' class="entrys"><span class="entry-title" onclick = "slider(this);">' . esc_html__( 'Brochure', 'adamas-custom-widgets' ) . '</span>';
			$output .= '<div class="entry-desc cf">';
			$output .= '<input id="' . esc_attr( $this->get_field_id( 'block-' . $i ) ) . '" name="' . esc_attr( $this->get_field_name( 'block-' . $i ) ) . '" type="hidden" value="' . esc_attr( $block ) . '">';

			// Brochure File
			$output .= '<p>';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'file_uri-' . $i ) ) . '">' . __( 'File URL', 'adamas-custom-widgets' ) . ':</label>';
			$output .= '<input type="text" name="' . esc_attr( $this->get_field_name( 'file_uri-' . $i ) ) . '" id="' . esc_attr( $this->get_field_id( 'file_uri-' . $i ) ) . '" value="' . esc_attr( $file_uri ) . '" />';
			$output .= '</p>';
			$output .= '<p>';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'target_blank-' . $i ) ) . '">' . __( 'Open in new tab', 'adamas-custom-widgets' ) . ':</label>';
			$output .= '<input type="checkbox" ' . checked( $instance[ 'target_blank-' . $i ], 'on', false ) . ' name="' . esc_attr( $this->get_field_name( 'target_blank-' . $i ) ) . '" id="' . esc_attr( $this->get_field_id( 'target_blank-' . $i ) ) . '" />';
			$output .= '</p>';

			// File extension and size checks
			$output .= '<p>';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'hide_extension-' . $i ) ) . '">' . __( 'Hide file extension', 'adamas-custom-widgets' ) . ':</label>';
			$output .= '<input type="checkbox" ' . checked( $instance[ 'hide_extension-' . $i ], 'on', false ) . ' name="' . esc_attr( $this->get_field_name( 'hide_extension-' . $i ) ) . '" id="' . esc_attr( $this->get_field_id( 'hide_extension-' . $i ) ) . '" />';
			$output .= '</p>';
			$output .= '<p>';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'hide_size-' . $i ) ) . '">' . __( 'Hide file size', 'adamas-custom-widgets' ) . ':</label>';
			$output .= '<input type="checkbox" ' . checked( $instance[ 'hide_size-' . $i ], 'on', false ) . ' name="' . esc_attr( $this->get_field_name( 'hide_size-' . $i ) ) . '" id="' . esc_attr( $this->get_field_id( 'hide_size-' . $i ) ) . '" />';
			$output .= '</p>';

			// Brochure name
			$output .= '<p class="last desc">';
			$output .= '<label for="' . esc_attr( $this->get_field_id( 'brochure_name-' . $i ) ) . '">' . __( 'Brochure Name', 'adamas-custom-widgets' ) . ':</label>';
			$output .= '<input type="text" name="' . esc_attr( $this->get_field_name( 'brochure_name-' . $i ) ) . '" id="' . esc_attr( $this->get_field_id( 'brochure_name-' . $i ) ) . '" value="' . esc_attr( $brochure_name ) . '" />';
			$output .= '</p>';

			$output .= '<p><a href="#delete"><span class="delete-row">' . esc_html__( 'Delete Row', 'adamas-custom-widgets' ) . '</span></a></p>';
			$output .= '</div></div>';
		}
		$output .= '</div></div>';
		$output .= '<div id="message">Sorry, you reached to the limit of "' . esc_attr( $max_entries ) . '" maximum entries.</div>';
		$output .= '<div class="' . esc_attr( $widget_add_id ) . '" style="display:none;">' . esc_html__( 'ADD BROCHURE', 'adamas-custom-widgets' ) . '</div>';
		?>
        <script>
          jQuery(document).ready(function(e) {
            jQuery.each(jQuery(".<?php echo esc_js( $widget_add_id ); ?>-input-containers #entries").children(), function() {
              if (jQuery(this).find('input').val() !== '') {
                jQuery(this).show();
              }
            });
            jQuery(".<?php echo esc_js( $widget_add_id ); ?>").bind('click', function(e) {
              var rows = 0;
              jQuery.each(jQuery(".<?php echo esc_js( $widget_add_id ); ?>-input-containers #entries").children(), function() {
                if (jQuery(this).find('input').val() === '') {
                  jQuery(this).find('.entry-title').addClass('active');
                  jQuery(this).find('.entry-desc').slideDown();
                  jQuery(this).find('input').first().val('0');
                  jQuery(this).show();
                  return false;
                } else {
                  rows++;
                  jQuery(this).show();
                  jQuery(this).find('.entry-title').removeClass('active');
                  jQuery(this).find('.entry-desc').slideUp();
                }
              });
              if (rows == '<?php echo esc_js( $max_entries );?>') {
                jQuery('#st-widget-container #message').show();
              }
            });
            jQuery('.delete-row').bind('click', function(e) {
              var count = 1;
              var current = jQuery(this).closest('.entrys').attr('id');
              jQuery.each(jQuery('#entries #' + current + ' .entry-desc').children(), function() {
                jQuery(this).val('');
              });
              jQuery.each(jQuery('#entries #' + current + ' .entry-desc p').children(), function() {
                jQuery(this).val('');
              });
              jQuery('#entries #' + current + ' .entry-title').removeClass('active');
              jQuery('#entries #' + current + ' .entry-desc').hide();
              jQuery('#entries #' + current).remove();
              jQuery.each(jQuery(".<?php echo esc_js( $widget_add_id ); ?>-input-containers #entries").children(), function() {
                if (jQuery(this).find('input').val() !== '') {
                  jQuery(this).find('input').first().val(count);
                }
                count++;
              });
            });
          });
        </script>
        <style>
            .cf:before, .cf:after {
                content: "";
                display: table;
            }

            .cf:after {
                clear: both;
            }

            .cf {
                zoom: 1;
            }

            .clear {
                clear: both;
            }

            .clearfix:after {
                content: ".";
                display: block;
                height: 0;
                clear: both;
                visibility: hidden;
            }

            .clearfix {
                display: inline-block;
            }

            * html .clearfix {
                height: 1%;
            }

            .clearfix {
                display: block;
            }

            #st-widget-container input {
                float: right;
                width: 60%;
            }

            #st-widget-container input[type="checkbox"] {
                float: none;
                width: auto;
                margin: 0 5px;
            }

            #st-widget-container label {
                width: 40%;
            }

            <?php echo '.'.esc_attr($widget_add_id); ?>
            {
                background: #ccc none repeat scroll 0 0
            ;
                font-weight: bold
            ;
                margin: 20px 0px 9px
            ;
                padding: 6px
            ;
                text-align: center
            ;
                display: block !important
            ;
                cursor: pointer
            ;
            }
            .block-image {
                width: 50px;
                height: 30px;
                float: right;
                display: none;
            }

            .desc {
                height: 55px;
            }

            #entries #remove-img {
                background: url('<?php echo get_template_directory_uri().'/assets/images/deleteimg.png'; ?>') center center no-repeat;
                width: 20px;
                height: 22px;
                display: none;
            }

            #entries {
                padding: 10px 0 0;
            }

            #entries .entrys {
                padding: 0;
                border: 1px solid #e5e5e5;
                margin: 10px 0 0;
                clear: both;
            }

            #entries .entrys:first-child {
                margin: 0;
            }

            #entries .delete-row {
                margin-top: 20px;
                float: right;
                text-decoration: underline;
                color: red;
            }

            #entries .entry-title {
                display: block;
                font-size: 14px;
                line-height: 18px;
                font-weight: 600;
                background: #f1f1f1;
                padding: 7px 5px;
                position: relative;
            }

            #entries .entry-title:after {
                content: '\f140';
                font: 400 20px/1 dashicons;
                position: absolute;
                right: 10px;
                top: 6px;
                color: #a0a5aa;
            }

            #entries .entry-title.active:after {
                content: '\f142';
            }

            #entries .entry-desc {
                display: none;
                padding: 0 10px 10px;
                border-top: 1px solid #e5e5e5;
            }

            #st-widget-container #entries p.last label {
                white-space: pre-line;
                float: left;
                width: 39%;
            }

            #message {
                padding: 6px;
                display: none;
                color: red;
                font-weight: bold;
            }
        </style>
        <div id="st-widget-container">
			<?php echo $output; ?>
        </div>
		<?php
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Brochure_Widget' );
} );

function st_brochure_widget_admin_enqueue() {
	wp_enqueue_style( 'thickbox' );
	wp_enqueue_script( 'media-upload' );
	wp_enqueue_script( 'thickbox' );
	wp_enqueue_script( 'st-widget-repeater', plugins_url( 'js/widget-repeater.js', __FILE__ ), false, null, false );
}

add_action( 'admin_enqueue_scripts', 'st_brochure_widget_admin_enqueue' );