<?php

class St_Adamas_Contact_Widget extends WP_Widget {

	function __construct() {
		$widget_ops = array( 'description' => esc_html__( 'Displays contact button with text.', 'adamas-custom-widgets' ) );
		parent::__construct( 'st_contact_widget', esc_html__( 'Contact', 'adamas-custom-widgets' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title = $before_title . apply_filters( 'widget_title', $instance['title'] ) . $after_title;
		$color = isset( $instance['color'] ) ? $instance['color'] : false;
		echo $before_widget;
		if ( ! empty( $instance['title'] ) ) {
			echo esc_html( $title );
		}
		?>
        <div class="st-contact-widget-inner<?php if ( $color ) { ?> second-color-scheme<?php } ?>">
            <div class="st-contact-widget-question"><?php echo wp_kses_post( $instance['quest'] ); ?></div>
            <div class="st-contact-widget-message"><?php echo wp_kses_post( wpautop( $instance['msg'] ) ); ?></div>
            <div class="st-contact-widget-button-wrapper"><a href="<?php echo esc_url( $instance['link'] ); ?>"
                                                             class="st-contact-widget-button"><span
                            class="st-contact-widget-button-text"><?php echo esc_html( $instance['button_text'] ); ?></span><span
                            class="st-contact-widget-button-icon"><i class="fa fa-angle-right"
                                                                     aria-hidden="true"></i></span></a></div>
        </div>
		<?php echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance                = $old_instance;
		$instance['title']       = sanitize_text_field( $new_instance['title'] );
		$instance['quest']       = wp_kses_post( $new_instance['quest'] );
		$instance['msg']         = wp_kses_post( $new_instance['msg'] );
		$instance['button_text'] = strip_tags( $new_instance['button_text'] );
		$instance['link']        = $new_instance['link'];
		$instance['color']       = isset( $new_instance['color'] ) ? (bool) $new_instance['color'] : false;

		return $instance;
	}

	function form( $instance ) {
		if ( ! isset( $instance['title'] ) ) {
			$instance['title'] = '';
		}
		$title  = esc_attr( $instance['title'] );
		$output = '<div class="cf">';
		$output .= '<p>';
		$output .= '<label class="st-contact-widget-title" for="' . esc_attr( $this->get_field_id( 'title' ) ) . '">' . esc_html__( 'Widget Title', 'adamas-custom-widgets' ) . ':</label>';
		$output .= '<input id="' . esc_attr( $this->get_field_id( 'title' ) ) . '" name="' . esc_attr( $this->get_field_name( 'title' ) ) . '" type="text" value="' . $title . '" />';

		if ( ! isset( $instance['quest'] ) ) {
			$instance['quest'] = '';
		}
		$quest  = esc_textarea( $instance['quest'] );
		$output .= '<p>';
		$output .= '<label class="st-contact-widget-quest" for="' . esc_attr( $this->get_field_id( 'quest' ) ) . '">' . esc_html__( 'Contact Question', 'adamas-custom-widgets' ) . ':</label>';
		$output .= '<textarea id="' . esc_attr( $this->get_field_name( 'quest' ) ) . '" name="' . esc_attr( $this->get_field_name( 'quest' ) ) . '">' . $quest . '</textarea>';
		$output .= '</p>';

		if ( ! isset( $instance['msg'] ) ) {
			$instance['msg'] = '';
		}
		$msg    = esc_textarea( $instance['msg'] );
		$output .= '<p>';
		$output .= '<label class="st-contact-widget-msg" for="' . esc_attr( $this->get_field_id( 'msg' ) ) . '">' . esc_html__( 'Contact Message', 'adamas-custom-widgets' ) . ':</label>';
		$output .= '<textarea rows="4" id="' . esc_attr( $this->get_field_name( 'msg' ) ) . '" name="' . esc_attr( $this->get_field_name( 'msg' ) ) . '">' . $msg . '</textarea>';
		$output .= '</p>';

		if ( ! isset( $instance['button_text'] ) ) {
			$instance['button_text'] = '';
		}
		$button_text = esc_attr( $instance['button_text'] );
		$output      .= '<p>';
		$output      .= '<label class="st-contact-widget-button-text" for="' . esc_attr( $this->get_field_id( 'button_text' ) ) . '">' . esc_html__( 'Button Text', 'adamas-custom-widgets' ) . ':</label>';
		$output      .= '<input id="' . esc_attr( $this->get_field_id( 'button_text' ) ) . '" name="' . esc_attr( $this->get_field_name( 'button_text' ) ) . '" type="text" value="' . $button_text . '" />';
		$output      .= '</p>';

		if ( ! isset( $instance['link'] ) ) {
			$instance['link'] = '';
		}
		$link   = esc_attr( $instance['link'] );
		$output .= '<p>';
		$output .= '<label class="st-contact-widget-link" for="' . esc_attr( $this->get_field_id( 'link' ) ) . '">' . esc_html__( 'Button Link', 'adamas-custom-widgets' ) . ':</label>';
		$output .= '<input id="' . esc_attr( $this->get_field_id( 'link' ) ) . '" name="' . esc_attr( $this->get_field_name( 'link' ) ) . '" type="text" value="' . $link . '" />';
		$output .= '</p>';

		$color  = isset( $instance['color'] ) ? (bool) $instance['color'] : false;
		$output .= '<p><input class="checkbox" type="checkbox"' . checked( $color, true, false ) . ' id="' . esc_attr( $this->get_field_id( 'color' ) ) . '" name="' . esc_attr( $this->get_field_name( 'color' ) ) . '" style="width:auto"/>';
		$output .= '<label for="' . esc_attr( $this->get_field_id( 'color' ) ) . '">' . esc_html__( 'Set secondary color scheme?', 'adamas-custom-widgets' ) . '</label></p>';

		$output .= '</div>';
		?>
        <div id="st-contact-widget-container">
			<?php echo $output; ?>
        </div>
		<?php
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Contact_Widget' );
} );