<?php
/*
 * Add-on Name: Blockquote Module
 */
if ( ! class_exists( 'St_Blockquote_Module' ) ) {
	class St_Blockquote_Module {
		function __construct() {
			add_shortcode( 'st_blockquote_module', array( $this, 'blockquote_module_shortcode' ) );
			add_action( 'init', array( $this, 'blockquote_module_init' ) );
		}

		function blockquote_module_shortcode( $atts, $content ) {
			$output = $font = $font_style = $font_size = $line_height = $letter_spacing = $el_class = $module_animation = $animation = $animated = '';

			extract( shortcode_atts( array(
				'font'             => '',
				'font_style'       => '',
				'font_size'        => '',
				'line_height'      => '',
				'letter_spacing'   => '',
				'module_animation' => '',
				'el_class'         => '',
			), $atts ) );

			$id = uniqid( 'st-blockquote-' );

			$blockquote_style = ' style="';

			if ( $font !== '' ) {
				$font_family = function_exists( 'get_ultimate_font_family' ) ? get_ultimate_font_family( $font ) : '';
				if ( $font_family !== '' ) {
					$blockquote_style .= ! empty( $font_family ) ? 'font-family:\'' . $font_family . '\';' : '';
				}
			}

			if ( $font_style !== '' ) {
				$blockquote_style .= esc_attr( $font_style );
			}

			if ( is_numeric( $font_size ) ) {
				$font_size = 'desktop:' . $font_size . 'px;';
			}

			if ( is_numeric( $line_height ) ) {
				$line_height = 'desktop:' . $line_height . 'px;';
			}

			$args = array(
				'target'      => "#" . $id . "",
				'media_sizes' => array(
					'font-size'   => $font_size,
					'line-height' => $line_height,
				),
			);

			$blockquote_responsive = get_ultimate_vc_responsive_media_css( $args );

			$blockquote_style .= $letter_spacing !== '' ? 'letter-spacing:' . esc_attr( $letter_spacing ) . 'px;' : '';
			$blockquote_style .= '"';

			$content = wpb_js_remove_wpautop( $content, true );

			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . esc_attr( $module_animation ) . '"';
			}

			$output .= '<div class="st-blockquote ult-responsive ' . esc_attr( $el_class ) . ' ' . esc_attr( $animated ) . '" ' . $animation . ' ' . $blockquote_style . ' ' . $blockquote_responsive . ' id="' . esc_attr( $id ) . '">' . do_shortcode( $content ) . '</div>';

			return $output;
		}

		function blockquote_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'                    => __( 'Blockquote', 'adamas-vc-shortcodes' ),
					'base'                    => 'st_blockquote_module',
					'category'                => esc_html__( 'ST Addons', 'adamas-vc-shortcodes' ),
					'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/blockquote.png',
					'show_settings_on_create' => true,
					'params'                  => array(
						array(
							'type'        => 'textarea_html',
							'heading'     => __( 'Quote', 'adamas-vc-shortcodes' ),
							'param_name'  => 'content',
							'description' => __( 'Enter text of quote.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'ultimate_google_fonts',
							'heading'     => __( 'Font family', 'adamas-vc-shortcodes' ),
							'param_name'  => 'font',
							'value'       => '',
							'description' => '',
						),
						array(
							'type'        => 'ultimate_google_fonts_style',
							'heading'     => __( 'Font style', 'adamas-vc-shortcodes' ),
							'param_name'  => 'font_style',
							'value'       => '',
							'description' => '',
						),
						array(
							'type'       => 'ultimate_responsive',
							'class'      => '',
							'heading'    => __( 'Font size', 'adamas-vc-shortcodes' ),
							'param_name' => 'font_size',
							'unit'       => 'px',
							'media'      => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => '',
							'heading'     => __( 'Line height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'line_height',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Letter spacing', 'adamas-vc-shortcodes' ),
							'param_name'  => 'letter_spacing',
							'value'       => '',
							'description' => '',
							'suffix'      => 'px',
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_blockquote_module = new St_Blockquote_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_blockquote_module extends WPBakeryShortCode {
		}
	}
}