<?php
/*
 * Add-on Name: Image Slider Module
 */
if ( ! class_exists( 'St_Image_Slider_Module' ) ) {
	class St_Image_Slider_Module {
		function __construct() {
			add_shortcode( 'st_image_slider_module', array( $this, 'image_slider_module_shortcode' ) );
			add_action( 'init', array( $this, 'image_slider_module_init' ) );
		}

		function image_slider_module_shortcode( $atts ) {
			$el_class = $slider_layout = $slider_height = $images = $module_animation = $animation = $animated = '';

			extract( shortcode_atts( array(
				'slider_layout'    => '',
				'slider_height'    => '',
				'images'           => '',
				'module_animation' => '',
				'el_class'         => '',
			), $atts ) );

			if ( empty( $slider_layout ) ) {
				$slider_layout = 'no-images';
			}

			$output = '';

			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . esc_attr( $module_animation ) . '"';
			}

			$gal_images = '';
			$link_start = '';
			$link_end   = '';
			$el_start   = '';
			$el_end     = '';

			$id = uniqid( 'st-image-slider-' );

			$el_start          = '<div class="st-image-slider-item">';
			$el_end            = '</div>';
			$slides_wrap_start = '<div class="st-image-slider" id="' . esc_attr( $id ) . '">';
			$slides_wrap_end   = '</div>';

			$pretty_rel_random = ' data-rel="prettyPhoto[rel-' . get_the_ID() . '-' . rand() . ']"';

			if ( '' === $images ) {
				$images = '-1,-2,-3';
			}
			$images = explode( ',', $images );

			if ( $slider_height ) {
				$height = 'height:' . esc_attr( $slider_height ) . 'px';
			} else {
				$height = '';
			}

			foreach ( $images as $i => $image ) {
				if ( $image > 0 ) {
					$img      = wp_get_attachment_image_src( $image, 'full' );
					$img_link = '<div class="st-image-slider-item" style="background-image:url(' . esc_url( $img[0] ) . ');' . $height . '"></div>';
				} else {
					// TODO : Add "No image" image link
				}

				$link_start = $link_end = '';
				$link_start = '<a rel="prettyPhoto[slides]" href="' . esc_url( $img[0] ) . '"' . $pretty_rel_random . '>';
				$link_end   = '</a>';

				$gal_images .= $el_start . $link_start . $img_link . $link_end . $el_end;
			}

			$output .= '<div class="st-image-slider-outer-wrapper">';
			$output .= '<div class="st-image-slider-wrapper ' . esc_attr( $el_class ) . '">' . $slides_wrap_start . $gal_images . $slides_wrap_end . '</div>';

			if ( $slider_layout == 'with-images' ) {
				$output .= '<div class="st-image-slider-thumbnails" id="' . esc_attr( $id ) . '-thumbnails">';
				foreach ( $images as $image ) {
					if ( $image > 0 ) {
						$thumbnail_link = wp_get_attachment_image_src( $image, 'full' );
						$thumbnail_div  = '<div class="st-image-slider-thumbnail" style="background-image:url(' . esc_url( $thumbnail_link[0] ) . ')"></div>';
					} else {
						// TODO : Add "No image" image link
					}
					$output .= $thumbnail_div;
				}
				$output .= '</div>'; // st-image-slider-thumbnails
			}
			$output .= '</div>'; // st-image-slider-outer-wrapper

			wp_enqueue_script( 'slick' );

			$rtl = '';
			if ( is_rtl() ) {
				$rtl = 'rtl:true';
			}

			if ( $slider_layout == 'with-images' ) {
				$output .= '<script type="text/javascript">
			(function($){
				"use strict";
				$(document).ready(function(){
					$("#' . esc_js( $id ) . '").slick({rows:0,infinite:false,adaptiveHeight:true,fade:true,cssEase:"linear",draggable:false,asNavFor:"#' . esc_js( $id ) . '-thumbnails",' . esc_js( $rtl ) . '});
					$("#' . esc_js( $id ) . '-thumbnails").slick({rows:0,slidesToShow:5,infinite:false,variableWidth:true,focusOnSelect:true,centerMode:false,draggable:false,asNavFor: "#' . esc_js( $id ) . '",' . esc_js( $rtl ) . '});
				})
			})(jQuery);
			</script>';
			} else {
				$output .= '<script type="text/javascript">
			(function($){
				"use strict";
				$(document).ready(function(){
					$("#' . esc_js( $id ) . '").slick({rows:0,infinite:false,adaptiveHeight:true,fade:true,cssEase:"linear",draggable:false,' . esc_js( $rtl ) . '});
				})
			})(jQuery);
			</script>';
			}

			return $output;
		}

		function image_slider_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Image Slider', 'adamas-vc-shortcodes' ),
					'base'        => 'st_image_slider_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/image_slider.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Images in slider', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Slider layout', 'adamas-vc-shortcodes' ),
							'param_name'  => 'slider_layout',
							'value'       => array(
								__( 'Slider only', 'adamas-vc-shortcodes' )               => 'no-images',
								__( 'With gallery images below', 'adamas-vc-shortcodes' ) => 'with-images',
							),
							'description' => '',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Slider height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'slider_height',
							'description' => '',
						),
						array(
							'type'        => 'attach_images',
							'class'       => '',
							'heading'     => __( 'Add images', 'adamas-vc-shortcodes' ),
							'param_name'  => 'images',
							'description' => ''
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_image_slider_module = new St_Image_Slider_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_image_slider_module extends WPBakeryShortCode {
		}
	}
}