<?php
/*
* Add-on Name: Pages Grid Module
*/
if ( ! class_exists( 'St_Pages_Grid_Module' ) ) {
	class St_Pages_Grid_Module {
		function __construct() {
			add_shortcode( 'st_pages_grid_module', array( $this, 'pages_grid_module_shortcode' ) );
			add_action( 'init', array( $this, 'pages_grid_module_init' ) );
		}

		function pages_grid_module_shortcode( $atts ) {
			$output = $pages_to_display = $link_text = $pages_grid_layout = $columns_padding = $el_class = $module_animation = $animation = $animated = $inner_animated = '';
			extract( shortcode_atts( array(
				'pages_to_display'  => '',
				'pages_grid_layout' => '',
				'column_padding'    => '',
				'item_padding'      => '',
				'column_amount'     => '',
				'link_text'         => '',
				'module_animation'  => '',
				'el_class'          => ''
			), $atts ) );

			// Animation
			if ( $module_animation ) {
				$animated       .= ' st-animation';
				$animation      .= 'data-animation="' . esc_attr( $module_animation ) . '"';
				$inner_animated .= 'data-animated=".st-pages-grid-item"';
			}

			if ( empty( $link_text ) ) {
				$read_more = esc_html__( 'Read more', 'adamas-vc-shortcodes' );
			} else {
				$read_more = $link_text;
			}

			if ( empty( $pages_to_display ) ) {
				$pages_to_display = false;
			}

			if ( empty( $pages_grid_layout ) ) {
				$pages_grid_layout = 'fitRows';
			}

			if ( empty( $column_amount ) ) {
				$column_amount = 'one-column';
			}

			if ( ! empty( $column_padding ) ) {
				$el_class .= ' ' . esc_attr( $column_padding );
			}

			if ( $column_amount == 'one-column' ) {
				$image_width = 1920;
			} elseif ( $column_amount == 'two-column' ) {
				$image_width = 960;
			} elseif ( $column_amount == 'three-column' ) {
				$image_width = 640;
			} else {
				$image_width = 480;
			}

			if ( strcmp( $pages_grid_layout, 'fitRows' ) === 0 ) {
				if ( $column_amount == 'one-column' ) {
					$image_height = 1280;
				} elseif ( $column_amount == 'two-column' ) {
					$image_height = 800;
				} elseif ( $column_amount == 'three-column' ) {
					$image_height = 533;
				} else {
					$image_height = 400;
				}
			} else {
				$image_height = 800;
			}

			$id = uniqid( 'st-pages-grid-' );

			$pages_array = preg_split( '/[\s,]+/', $pages_to_display );

			if ( ! isset( $pages_to_display ) || empty( $pages_to_display ) ) {
				$args = array(
					'post_type'      => 'page',
					'posts_per_page' => 9999,
				);
			} else {
				$args = array(
					'post_type'      => 'page',
					'post__in'       => $pages_array,
					'posts_per_page' => 9999,
				);
			}

			$output = '<div class="st-pages-grid-module-container">';
			$output .= '<div class="st-pages-grid-module' . esc_attr( $el_class ) . '" id="' . esc_attr( $id ) . '">';

			$output      .= '<div class="st-pages-grid-items ' . esc_attr( $pages_grid_layout ) . ' ' . esc_attr( $column_amount ) . ' ' . esc_attr( $animated ) . '" ' . $inner_animated . ' ' . $animation . '>';
			$pages_query = new WP_Query( $args );
			while ( $pages_query->have_posts() ) : $pages_query->the_post();
				if ( has_post_thumbnail() ) {
					$thumbnail = get_post_thumbnail_id();
					$image_url = wp_get_attachment_url( $thumbnail, 'full' );
					if ( strcmp( $pages_grid_layout, 'fitRows' ) === 0 ) {
						$post_image = st_adamas_aq_resize( $image_url, $image_width, $image_height, true, true, true );
					} else {
						$post_image = st_adamas_aq_resize( $image_url, $image_width, $image_height, false, true, true );
					}
					if ( ! $post_image ) {
						$post_image = $image_url;
					}
				}

				$output .= '<div class="st-pages-grid-item">';
				if ( has_post_thumbnail() ) {
					$output .= '<div class="st-pages-grid-item-thumbnail"><a href="' . esc_url( get_permalink() ) . '"><div class="st-pages-grid-item-overlay"><div class="overlay-inner-icon"></div><div class="overlay-inner-left"></div><div class="overlay-inner-right"></div></div>';
					$output .= '<img src="' . esc_url( $post_image ) . '" alt="' . esc_attr( get_the_title() ) . '" />';
					$output .= '</a></div>'; // st-pages-grid-item-thumbnail
				}
				$output .= '<div class="st-pages-grid-item-title"><a href="' . esc_url( get_permalink() ) . '"><h4>' . esc_attr( get_the_title() ) . '</h4></a></div>';
				$output .= '<div class="st-pages-grid-item-excerpt">' . wp_kses_post( get_the_excerpt() ) . '</div>'; // TODO : If excerpt too long ...
				$output .= '<div class="st-pages-grid-item-read-more"><a href="' . esc_url( get_permalink() ) . '">' . esc_html( $read_more ) . '</a></div>';
				$output .= '</div>'; // st-pages-grid-item

			endwhile;
			wp_reset_postdata();

			wp_enqueue_script( 'isotope', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', false, null, true );
			wp_enqueue_script( 'pages_masonry', get_template_directory_uri() . '/assets/js/pages.masonry.js', array( 'jquery' ), null, true );

			$output .= '<script type="text/javascript">';
			$output .= '(function($){';
			$output .= '"use strict";';
			$output .= '$(document).ready(function(){';
			$output .= '$("#' . esc_js( $id ) . '").StPagesModule("' . esc_js( $pages_grid_layout ) . '");';
			$output .= '});';
			$output .= '})(jQuery);';
			$output .= '</script>';

			$output .= '</div>'; // st-pages-grid-items
			$output .= '</div>'; // st-pages-grid-module
			$output .= '</div>'; // st-pages-grid-module-container

			return $output;
		}

		function pages_grid_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Pages Grid', 'adamas-vc-shortcodes' ),
					'base'        => 'st_pages_grid_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/pages_grid.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Pages in grid', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'       => 'checkbox',
							'class'      => '',
							'heading'    => __( 'Pages to display', 'adamas-vc-shortcodes' ),
							'param_name' => 'pages_to_display',
							'value'      => st_adamas_single_page_select(),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Column amount', 'adamas-vc-shortcodes' ),
							'param_name'  => 'column_amount',
							'value'       => array(
								__( 'One column', 'adamas-vc-shortcodes' )    => 'one-column',
								__( 'Two columns', 'adamas-vc-shortcodes' )   => 'two-column',
								__( 'Three columns', 'adamas-vc-shortcodes' ) => 'three-column',
								__( 'Four columns', 'adamas-vc-shortcodes' )  => 'four-column',
							),
							'description' => __( 'Select column amount.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Grid layout', 'adamas-vc-shortcodes' ),
							'param_name'  => 'pages_grid_layout',
							'value'       => array(
								__( 'Grid', 'adamas-vc-shortcodes' )    => 'fitRows',
								__( 'Masonry', 'adamas-vc-shortcodes' ) => 'masonry',
							),
							'description' => __( 'Select pages grid layout. Masonry works only for 2-4 columns.', 'adamas-vc-shortcodes' ),
							'dependency'  => Array( 'element' => 'column_amount', 'value' => array( 'two-column', 'three-column', 'four-column' ) ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Columns padding', 'adamas-vc-shortcodes' ),
							'param_name'  => 'column_padding',
							'value'       => array(
								__( 'No padding', 'adamas-vc-shortcodes' )     => '',
								__( 'Narrow padding', 'adamas-vc-shortcodes' ) => 'st-narrow-padding',
								__( 'Normal padding', 'adamas-vc-shortcodes' ) => 'st-normal-padding',
							),
							'description' => __( 'Select padding between columns.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Link text', 'adamas-vc-shortcodes' ),
							'param_name'  => 'link_text',
							'description' => __( 'Please, set text for link (e.g. "Read more").', 'adamas-vc-shortcodes' )
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_pages_grid_module = new St_Pages_Grid_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_pages_grid_module extends WPBakeryShortCode {
		}
	}
}