<?php
/*
* Add-on Name: Simple Contact Box Module
*/
if ( ! class_exists( 'St_Simple_Contact_Box_Module' ) ) {
	class St_Simple_Contact_Box_Module {
		function __construct() {
			add_shortcode( 'st_simple_contact_box_module', array( $this, 'simple_contact_box_module_shortcode' ) );
			add_action( 'init', array( $this, 'simple_contact_box_module_init' ) );
		}

		function simple_contact_box_module_shortcode( $atts, $content ) {
			$output = $simple_contact_box_title = $simple_contact_box_icon_color = $simple_contact_box_content_color = $icon_type = $icon_img = $icon = $module_animation = $animation = $animated = '';

			extract( shortcode_atts( array(
				'simple_contact_box_title'         => '',
				'simple_contact_box_content_color' => '',
				'simple_contact_box_icon_color'    => '',
				'simple_contact_box_content_color' => '',
				'icon_type'                        => '',
				'icon_img'                         => '',
				'icon'                             => '',
				'module_animation'                 => '',
				'el_class'                         => '',
			), $atts ) );


			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . esc_attr( $module_animation ) . '"';
			}

			$content = wpb_js_remove_wpautop( $content, true );

			$output .= '<div class="st-simple-contact-box ' . esc_attr( $el_class ) . '">';
			$output .= '<div class="st-simple-contact-box-inner ' . esc_attr( $animated ) . '" ' . $animation . '>';
			$output .= '<div class="st-simple-contact-box-icon">';
			if ( $icon_type == 'custom' ) {
				$img = apply_filters( 'ult_get_img_single', $icon_img, 'url' );
				$alt = apply_filters( 'ult_get_img_single', $icon_img, 'alt' );

				if ( ! empty( $icon_img ) ) {
					$output .= '<div class="st-simple-contact-box-icon-image">';
					$output .= '<img src="' . esc_url( $img ) . '" alt="' . esc_attr( $alt ) . '"/>';
					$output .= '</div>';
				}
			} else {
				$style = '';
				if ( $simple_contact_box_icon_color !== '' ) {
					$style .= 'style="color:' . esc_attr( $simple_contact_box_icon_color ) . '"';
				}
				if ( $icon !== '' ) {
					$output .= '<i class="' . esc_attr( $icon ) . '" ' . $style . '></i>';
				}
			}
			$output        .= '</div>'; // st-simple-contact-box-icon
			$content_style = '';
			if ( $simple_contact_box_content_color !== '' ) {
				$content_style .= 'style="color:' . esc_attr( $simple_contact_box_content_color ) . '"';
			}
			$output .= '<div class="st-simple-contact-box-info" ' . $content_style . '>';
			$output .= '<div class="st-simple-contact-box-title"><h4>' . esc_attr( $simple_contact_box_title ) . '</h4></div>';
			$output .= '<div class="st-simple-contact-box-desc">' . do_shortcode( $content ) . '</div>';
			$output .= '</div>'; // st-simple-contact-box-info
			$output .= '</div>'; // st-simple-contact-box-inner
			$output .= '</div>'; // st-simple-contact-box

			return $output;
		}

		function simple_contact_box_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Simple Contact Box', 'adamas-vc-shortcodes' ),
					'base'        => 'st_simple_contact_box_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/simple_contact_box.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Displays simple contact box', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Module title', 'adamas-vc-shortcodes' ),
							'param_name'  => 'simple_contact_box_title',
							'description' => '',
							'admin_label' => true,
						),
						array(
							'type'        => 'textarea_html',
							'heading'     => __( 'Module description', 'adamas-vc-shortcodes' ),
							'param_name'  => 'content',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'class'       => '',
							'heading'     => __( 'Content color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'simple_contact_box_content_color',
							'value'       => '',
							'description' => __( 'Select color for module content.', 'adamas-vc-shortcodes' ),
						),
						array(
							"type"        => "dropdown",
							"class"       => "",
							"heading"     => __( "Icon to display:", "adamas-vc-shortcodes" ),
							"param_name"  => "icon_type",
							"value"       => array(
								__( "Font Icon Manager", "adamas-vc-shortcodes" ) => "selector",
								__( "Custom Image Icon", "adamas-vc-shortcodes" ) => "custom",
							),
							"description" => __( "Use an existing font icon or upload a custom image.", "adamas-vc-shortcodes" )
						),
						array(
							"type"        => "ult_img_single",
							"class"       => "",
							"heading"     => __( "Upload Image Icon:", "adamas-vc-shortcodes" ),
							"param_name"  => "icon_img",
							"value"       => "",
							"description" => __( "Upload the custom image icon.", "adamas-vc-shortcodes" ),
							"dependency"  => Array( "element" => "icon_type", "value" => array( "custom" ) ),
						),
						array(
							"type"        => "icon_manager",
							"class"       => "",
							"heading"     => __( "Select Icon ", "adamas-vc-shortcodes" ),
							"param_name"  => "icon",
							"value"       => "",
							"description" => __( "Click and select icon of your choice. If you can't find the one that suits for your purpose, you can <a href='admin.php?page=bsf-font-icon-manager' target='_blank'>add new here</a>.", "smile" ),
							"dependency"  => Array( "element" => "icon_type", "value" => array( "selector" ) ),
						),
						array(
							'type'        => 'colorpicker',
							'class'       => '',
							'heading'     => __( 'Color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'simple_contact_box_icon_color',
							'value'       => '',
							'description' => __( 'Give it a nice paint!', 'adamas-vc-shortcodes' ),
							"dependency"  => Array( "element" => "icon_type", "value" => array( "selector" ) ),
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
					)
				) );
			}
		}
	}

	$st_simple_contact_box_module = new St_Simple_Contact_Box_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_simple_contact_box_module extends WPBakeryShortCode {
		}
	}
}