<?php
/*
* Add-on Name: Single Project Module
*/
if ( ! class_exists( 'St_Single_Project_Module' ) ) {
	class St_Single_Project_Module {
		function __construct() {
			add_shortcode( 'st_single_project_module', array( $this, 'projects_portfolio_module_shortcode' ) );
			add_action( 'init', array( $this, 'projects_portfolio_module_init' ) );
		}

		function projects_portfolio_module_shortcode( $atts, $content ) {
			$output = $project_title = $project_subtitle = $project_image = $project_icon = $project_link = '';

			extract( shortcode_atts( array(
				'project_title'    => '',
				'project_subtitle' => '',
				'project_image'    => '',
				'project_icon'     => '',
				'project_link'     => '',
				'module_animation' => '',
				'el_class'         => '',
			), $atts ) );

			$img      = wp_get_attachment_image_src( $atts['project_image'], 'full' );
			$img_link = $img[0];

			$project_link = $atts['project_link'];
			$project_link = vc_build_link( $project_link );
			$link_url     = $project_link['url'];
			$link_target  = $project_link['target'];

			if ( ! empty( $project_link['rel'] ) ) {
				$rel = ' rel="' . esc_attr( $project_link['rel'] ) . '"';
			} else {
				$rel = '';
			}

			if ( $img ) {
				$bg_img = ' style="background-image:url(' . esc_url( $img_link ) . ');"';
			}

			$content = wpb_js_remove_wpautop( $content, true );

			$output .= '<div class="st-single-project ' . esc_attr( $el_class ) . '" ' . $bg_img . '>';
			$output .= '<div class="st-single-project-inner">';
			$output .= '<div class="st-single-project-bg"></div>';
			$output .= '<div class="st-single-project-info">';
			if ( $project_icon ) {
				$output .= '<i class="' . esc_attr( $project_icon ) . '"></i>';
			}
			$output .= '<div class="st-single-project-title"><h3>' . esc_attr( $project_title ) . '</h3><span>' . esc_attr( $project_subtitle ) . '</span></div>';
			$output .= '<div class="st-single-project-desc">' . do_shortcode( $content ) . '</div>';
			$output .= '</div>'; // st-single-project-info
			if ( ! empty( $link_url ) ) {
				$output .= '<div class="st-single-project-link"><a href="' . esc_url( $link_url ) . '" title="' . esc_attr( $project_title ) . '"';
				if ( $link_target != '' ) {
					$output .= ' target="' . esc_attr( trim( $link_target ) ) . '" ' . $rel . '>';
				} else {
					$output .= $rel . '>';
				}
				$output .= __( 'Read more', 'adamas-vc-shortcodes' );
				$output .= '</a></div>'; // st-single-project-link
			}
			$output .= '<div class="st-single-project-overlay-left"></div><div class="st-single-project-overlay-right"></div>';
			$output .= '</div>'; // st-single-project-inner
			$output .= '</div>'; // st-single-project

			return $output;
		}

		function projects_portfolio_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Single Project Item', 'adamas-vc-shortcodes' ),
					'base'        => 'st_single_project_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/simple_projects_item.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Displays single project', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Single project title', 'adamas-vc-shortcodes' ),
							'param_name'  => 'project_title',
							'description' => '',
							'admin_label' => true
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Single project subtitle', 'adamas-vc-shortcodes' ),
							'param_name'  => 'project_subtitle',
							'description' => '',
						),
						array(
							'type'        => 'attach_image',
							'heading'     => __( 'Single project image', 'adamas-vc-shortcodes' ),
							'param_name'  => 'project_image',
							'description' => '',
						),
						array(
							'type'        => 'icon_manager',
							'heading'     => __( 'Single project icon', 'adamas-vc-shortcodes' ),
							'param_name'  => 'project_icon',
							'description' => '',
						),
						array(
							'type'        => 'textarea_html',
							'heading'     => __( 'Single project description', 'adamas-vc-shortcodes' ),
							'param_name'  => 'content',
							'description' => '',
						),
						array(
							'type'        => 'vc_link',
							'heading'     => __( 'Single project link', 'adamas-vc-shortcodes' ),
							'param_name'  => 'project_link',
							'description' => '',
						),
					)
				) );
			}
		}
	}

	$st_single_project_module = new St_Single_Project_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_single_project_module extends WPBakeryShortCode {
		}
	}
}