<?php
/*
* Add-on Name: Vertical Text Block Module
*/
if ( ! class_exists( 'St_Vertical_Text_Block' ) ) {
	class St_Vertical_Text_Block {
		function __construct() {
			add_shortcode( 'st_vertical_text_block', array( $this, 'vertical_text_block_shortcode' ) );
			add_action( 'init', array( $this, 'vertical_text_block_init' ) );
		}

		function vertical_text_block_shortcode( $atts ) {
			$output                             = $vertical_text_title = $vertical_text_image = $vertical_text_title_color = $vertical_text_title_color_hover = '';
			$vertical_text_title_bg_color       = $vertical_text_title_bg_color_hover = $vertical_text_button_text = $vertical_text_button_link = '';
			$vertical_text_title_font           = $vertical_text_title_font_style = $vertical_text_title_font_size = $vertical_text_title_line_height = '';
			$vertical_text_title_letter_spacing = $bg_style = $el_class = '';
			$vertical_text_button_reverse       = '';

			extract( shortcode_atts( array(
				'vertical_text_block_layout'         => '',
				'vertical_text_title'                => '',
				'vertical_text_image'                => '',
				'vertical_text_title_color'          => '',
				'vertical_text_title_color_hover'    => '',
				'vertical_text_title_bg_color'       => '',
				'vertical_text_title_bg_color_hover' => '',
				'vertical_text_button_text'          => '',
				'vertical_text_button_link'          => '',
				'vertical_text_title_font'           => '',
				'vertical_text_title_font_style'     => '',
				'vertical_text_title_font_size'      => '',
				'vertical_text_title_line_height'    => '',
				'vertical_text_button_reverse'       => '',
				'vertical_text_title_letter_spacing' => '',
				'el_class'                           => '',
			), $atts ) );

			$id = uniqid( 'st-vertical-text-block-' );

			$image      = wp_get_attachment_image_src( $vertical_text_image, 'full' );
			$image_link = $image[0];

			if ( empty( $vertical_text_block_layout ) ) {
				$vertical_text_block_layout = 'st-title-left';
			}

			if ( ! empty( $image_link ) ) {
				$bg_style = 'style="background-image:url(' . esc_url( $image_link ) . ')"';
			}

			$title_style = 'style="';

			if ( $vertical_text_title_font !== '' ) {
				$title_font_family = function_exists( 'get_ultimate_font_family' ) ? get_ultimate_font_family( $vertical_text_title_font ) : '';
				$title_style       .= ! empty( $title_font_family ) ? 'font-family:\'' . $title_font_family . '\';' : '';
			}
			if ( $vertical_text_title_font_style !== '' ) {
				$title_style .= esc_attr( $vertical_text_title_font_style );
			}

			if ( is_numeric( $vertical_text_title_font_size ) ) {
				$vertical_text_title_font_size = 'desktop: ' . $vertical_text_title_font_size . 'px;';
			}
			if ( is_numeric( $vertical_text_title_line_height ) ) {
				$vertical_text_title_line_height = 'desktop: ' . $vertical_text_title_line_height . 'px;';
			}

			$title_args = array(
				'target'      => '#' . $id . ' .st-vertical-text-block-title',
				'media_sizes' => array(
					'font-size'   => $vertical_text_title_font_size,
					'line-height' => $vertical_text_title_line_height,
				),
			);

			$title_responsive = get_ultimate_vc_responsive_media_css( $title_args );
			$title_style      .= $vertical_text_title_letter_spacing !== '' ? 'letter-spacing:' . esc_attr( $vertical_text_title_letter_spacing ) . 'px;' : '';
			$title_style      .= $vertical_text_title_color !== '' ? 'color:' . esc_attr( $vertical_text_title_color ) . ';' : '';
			$title_style      .= '"';

			if ( $vertical_text_title_bg_color !== '' ) {
				$title_wrapper_style = ' style="';
				$title_wrapper_style .= $vertical_text_title_bg_color !== '' ? 'background:' . esc_attr( $vertical_text_title_bg_color ) . ';' : '';
				$title_wrapper_style .= '"';
			} else {
				$title_wrapper_style = '';
			}

			if ( $vertical_text_button_reverse ) {
				$button_style = ' style="';
				$button_style .= $vertical_text_title_color_hover !== '' ? 'color:#FFFFFF; border:none; background-color:' . $vertical_text_title_color_hover . ';' : '';
				$button_style .= '"';
			} else {
				$button_style = ' style="';
				$button_style .= $vertical_text_title_color !== '' ? 'color:' . esc_attr( $vertical_text_title_bg_color ) . '; border-color:' . esc_attr( $vertical_text_title_bg_color ) . '' : '';
				$button_style .= '"';
			}

			$hover_style = '';

			$overlay_gradient = '';
			$overlay_gradient .= 'style="
			background: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0), ' . ultimate_hex2rgb( esc_attr( $vertical_text_title_bg_color ), 0.5 ) . ' 100%);
			background: -webkit-gradient(left bottom, right top, color-stop(0%, rgba(255, 255, 255, 0)), color-stop(100%, ' . ultimate_hex2rgb( esc_attr( $vertical_text_title_bg_color ), 0.5 ) . '));
			background: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0) 0%, ' . ultimate_hex2rgb( esc_attr( $vertical_text_title_bg_color ), 0.5 ) . ' 100%);
			background: -o-linear-gradient(45deg, rgba(255, 255, 255, 0) 0%, ' . ultimate_hex2rgb( esc_attr( $vertical_text_title_bg_color ), 0.5 ) . ' 100%);
			background: -ms-linear-gradient(45deg, rgba(255, 255, 255, 0) 0%, ' . ultimate_hex2rgb( esc_attr( $vertical_text_title_bg_color ), 0.5 ) . ' 100%);
			background: linear-gradient(45deg, rgba(255, 255, 255, 0) 0%, ' . ultimate_hex2rgb( esc_attr( $vertical_text_title_bg_color ), 0.5 ) . ' 100%);
			"';

			if ( $vertical_text_title_color_hover != '' || $vertical_text_title_bg_color_hover != '' ) {
				$hover_style .= '<style type="text/css">';
				if ( $vertical_text_title_color_hover != '' ) {
					$hover_style .= '#' . esc_attr( $id ) . ':hover .st-vertical-text-block-title{color:' . esc_attr( $vertical_text_title_color_hover ) . ' !important}';
				}
				if ( $vertical_text_title_bg_color_hover != '' ) {
					$hover_style .= '#' . esc_attr( $id ) . ':hover .st-vertical-text-block-title-wrapper{background:' . esc_attr( $vertical_text_title_bg_color_hover ) . ' !important}';
				}
				$hover_style .= '</style>';
			}

			$output .= '<div class="st-vertical-text-block" id="' . esc_attr( $id ) . '">';
			if ( $vertical_text_block_layout == 'st-title-left' ) {
				$output .= '<div class="st-vertical-text-block-title-wrapper" ' . $title_wrapper_style . '>';
				$output .= '<h3 class="st-vertical-text-block-title ult-responsive" ' . $title_style . ' ' . $title_responsive . '>' . esc_attr( $vertical_text_title ) . '</h3>';
				$output .= '</div>'; // st-vertical-text-block-title-wrapper
			}
			$output .= '<div class="st-vertical-text-block-image">';
			$output .= '<div class="st-vertical-text-block-background" ' . $bg_style . '><div class="st-overlay" ' . $overlay_gradient . '></div></div>';

			$output .= '<div class="st-vertical-text-block-button" ' . $button_style . '><a href="' . esc_url( $vertical_text_button_link ) . '"><span class="st-vertical-text-block-button-text">' . esc_attr( $vertical_text_button_text ) . '</span><span class="st-vertical-text-block-button-icon"><i class="fa fa-angle-right" aria-hidden="true"></i></span></a></div>';
			$output .= '</div>'; // st-vertical-text-block-image
			if ( $vertical_text_block_layout == 'st-title-right' ) {
				$output .= '<div class="st-vertical-text-block-title-wrapper" ' . $title_wrapper_style . '>';
				$output .= '<h3 class="st-vertical-text-block-title ult-responsive" ' . $title_style . ' ' . $title_responsive . '>' . esc_attr( $vertical_text_title ) . '</h3>';
				$output .= '</div>'; // st-vertical-text-block-title-wrapper
			}
			$output .= '</div>'; // st-vertical-text-block

			if ( $hover_style != '' ) {
				$output .= "<script type=\"text/javascript\">jQuery(document).ready(function(){jQuery('head').append('" . $hover_style . "');});</script>";
			}

			return $output;
		}

		function vertical_text_block_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'                    => __( 'Vertical Text Block', 'adamas-vc-shortcodes' ),
					'base'                    => 'st_vertical_text_block',
					'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/vertical_text_block.png',
					'category'                => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'show_settings_on_create' => true,
					'params'                  => array(
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Block layout', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_block_layout',
							'description' => '',
							'value'       => array(
								__( 'Title on the left', 'adamas-vc-shortcodes' )  => 'st-title-left',
								__( 'Title on the right', 'adamas-vc-shortcodes' ) => 'st-title-right',
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Title', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title',
							'description' => '',
							'admin_label' => true,
						),
						array(
							'type'        => 'attach_image',
							'heading'     => __( 'Image', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_image',
							'value'       => '',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Title color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_color',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Title color on hover', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_color_hover',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Background color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_bg_color',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Background color on hover', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_bg_color_hover',
							'description' => '',
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Button text', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_button_text',
							'description' => '',
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Button link', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_button_link',
							'description' => '',
						),
						array(
							'type'        => 'checkbox',
							'heading'     => __( 'Background check for button', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_button_reverse',
							'description' => __( 'Check if button is placed on light background.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'ultimate_google_fonts',
							'heading'     => __( 'Title font family', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_font',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_google_fonts_style',
							'heading'     => __( 'Title font style', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_font_style',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'       => 'ultimate_responsive',
							'class'      => '',
							'heading'    => __( 'Title font size', 'adamas-vc-shortcodes' ),
							'param_name' => 'vertical_text_title_font_size',
							'unit'       => 'px',
							'media'      => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'group'      => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => '',
							'heading'     => __( 'Title line height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_line_height',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Title letter spacing', 'adamas-vc-shortcodes' ),
							'param_name'  => 'vertical_text_title_letter_spacing',
							'value'       => '',
							'description' => '',
							'suffix'      => 'px',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_vertical_text_block = new St_Vertical_Text_Block;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_vertical_text_block extends WPBakeryShortCode {
		}
	}
}