<?php
/*
* Add-on Name: Stats Counter for WPBakery Page Builder
* Add-on URI: http://dev.brainstormforce.com
*/
if ( ! class_exists( 'AIO_Stats_Counter' ) ) {
	class AIO_Stats_Counter {
		// constructor
		function __construct() {
			if ( Ultimate_VC_Addons::$uavc_editor_enable ) {
				add_action( 'init', array( $this, 'counter_init' ) );
			}
			add_action( "wp_enqueue_scripts", array( $this, "register_counter_assets" ), 1 );
			add_shortcode( 'stat_counter', array( $this, 'counter_shortcode' ) );
		}

		function register_counter_assets() {

			Ultimate_VC_Addons::ultimate_register_script( 'ult-stats-counter-js', 'countUp', false, array( 'jquery' ), ULTIMATE_VERSION, false );

			Ultimate_VC_Addons::ultimate_register_style( 'ult-stats-counter-style', 'stats-counter' );
		}

		// initialize the mapping function
		function counter_init() {
			if ( function_exists( 'vc_map' ) ) {
				// map with visual
				vc_map(
					array(
						"name"        => __( "Counter", "adamas-vc-shortcodes" ),
						"base"        => "stat_counter",
						"class"       => "vc_stats_counter",
						"icon"        => "vc_icon_stats",
						"category"    => "Ultimate VC Addons",
						"description" => __( "Your milestones, achievements, etc.", "adamas-vc-shortcodes" ),
						"params"      => array(
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Icon to display:", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_type",
								"value"       => array(
									__( "Font Icon Manager", "adamas-vc-shortcodes" ) => "selector",
									__( "Custom Image Icon", "adamas-vc-shortcodes" ) => "custom",
								),
								"description" => __( "Use an existing font icon or upload a custom image.", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "icon_manager",
								"class"       => "",
								"heading"     => __( "Select Icon ", "adamas-vc-shortcodes" ),
								"param_name"  => "icon",
								"value"       => "",
								"description" => __( "Click and select icon of your choice. If you can't find the one that suits for your purpose", "adamas-vc-shortcodes" ) . ", " . __( "you can", "adamas-vc-shortcodes" ) . " <a href='admin.php?page=bsf-font-icon-manager' target='_blank' rel='noopener'>" . __( "add new here", "adamas-vc-shortcodes" ) . "</a>.",
								"dependency"  => Array( "element" => "icon_type", "value" => array( "selector" ) ),
							),
							array(
								"type"        => "attach_image",
								"class"       => "",
								"heading"     => __( "Upload Image Icon:", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_img",
								"value"       => "",
								"description" => __( "Upload the custom image icon.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_type", "value" => array( "custom" ) ),
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Image Width", "adamas-vc-shortcodes" ),
								"param_name"  => "img_width",
								"value"       => 48,
								"min"         => 16,
								"max"         => 512,
								"suffix"      => "px",
								"description" => __( "Provide image width", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_type", "value" => array( "custom" ) ),
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Size of Icon", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_size",
								"value"       => 32,
								"min"         => 12,
								"max"         => 72,
								"suffix"      => "px",
								"description" => __( "How big would you like it?", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_type", "value" => array( "selector" ) ),
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Color", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_color",
								"value"       => "#333333",
								"description" => __( "Give it a nice paint!", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_type", "value" => array( "selector" ) ),
							),
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Icon Style", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_style",
								"value"       => array(
									__( "Simple", "adamas-vc-shortcodes" )            => "none",
									__( "Circle Background", "adamas-vc-shortcodes" ) => "circle",
									__( "Square Background", "adamas-vc-shortcodes" ) => "square",
									__( "Design your own", "adamas-vc-shortcodes" )   => "advanced",
								),
								"description" => __( "We have given three quick preset if you are in a hurry. Otherwise, create your own with various options.", "adamas-vc-shortcodes" ),
								//"dependency" => Array("element" => "icon_type","value" => array("selector")),
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Background Color", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_color_bg",
								"value"       => "#ffffff",
								"description" => __( "Select background color for icon.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_style", "value" => array( "circle", "square", "advanced" ) ),
							),
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Icon Border Style", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_border_style",
								"value"       => array(
									__( "None", "adamas-vc-shortcodes" )   => "",
									__( "Solid", "adamas-vc-shortcodes" )  => "solid",
									__( "Dashed", "adamas-vc-shortcodes" ) => "dashed",
									__( "Dotted", "adamas-vc-shortcodes" ) => "dotted",
									__( "Double", "adamas-vc-shortcodes" ) => "double",
									__( "Inset", "adamas-vc-shortcodes" )  => "inset",
									__( "Outset", "adamas-vc-shortcodes" ) => "outset",
								),
								"description" => __( "Select the border style for icon.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_style", "value" => array( "advanced" ) ),
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Border Color", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_color_border",
								"value"       => "#333333",
								"description" => __( "Select border color for icon.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_border_style", "not_empty" => true ),
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Border Width", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_border_size",
								"value"       => 1,
								"min"         => 1,
								"max"         => 10,
								"suffix"      => "px",
								"description" => __( "Thickness of the border.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_border_style", "not_empty" => true ),
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Border Radius", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_border_radius",
								"value"       => 500,
								"min"         => 1,
								"max"         => 500,
								"suffix"      => "px",
								"description" => __( "0 pixel value will create a square border. As you increase the value, the shape convert in circle slowly. (e.g 500 pixels).", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_border_style", "not_empty" => true ),
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Background Size", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_border_spacing",
								"value"       => 50,
								"min"         => 0,
								"max"         => 500,
								"suffix"      => "px",
								"description" => __( "Spacing from center of the icon till the boundary of border / background", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "icon_style", "value" => array( "advanced" ) ),
							),
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Animation", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_animation",
								"value"       => array(
									__( "No Animation", "adamas-vc-shortcodes" )       => "",
									__( "Swing", "adamas-vc-shortcodes" )              => "swing",
									__( "Pulse", "adamas-vc-shortcodes" )              => "pulse",
									__( "Fade In", "adamas-vc-shortcodes" )            => "fadeIn",
									__( "Fade In Up", "adamas-vc-shortcodes" )         => "fadeInUp",
									__( "Fade In Down", "adamas-vc-shortcodes" )       => "fadeInDown",
									__( "Fade In Left", "adamas-vc-shortcodes" )       => "fadeInLeft",
									__( "Fade In Right", "adamas-vc-shortcodes" )      => "fadeInRight",
									__( "Fade In Up Long", "adamas-vc-shortcodes" )    => "fadeInUpBig",
									__( "Fade In Down Long", "adamas-vc-shortcodes" )  => "fadeInDownBig",
									__( "Fade In Left Long", "adamas-vc-shortcodes" )  => "fadeInLeftBig",
									__( "Fade In Right Long", "adamas-vc-shortcodes" ) => "fadeInRightBig",
									__( "Slide In Down", "adamas-vc-shortcodes" )      => "slideInDown",
									__( "Slide In Left", "adamas-vc-shortcodes" )      => "slideInLeft",
									__( "Slide In Left", "adamas-vc-shortcodes" )      => "slideInLeft",
									__( "Bounce In", "adamas-vc-shortcodes" )          => "bounceIn",
									__( "Bounce In Up", "adamas-vc-shortcodes" )       => "bounceInUp",
									__( "Bounce In Down", "adamas-vc-shortcodes" )     => "bounceInDown",
									__( "Bounce In Left", "adamas-vc-shortcodes" )     => "bounceInLeft",
									__( "Bounce In Right", "adamas-vc-shortcodes" )    => "bounceInRight",
									__( "Rotate In", "adamas-vc-shortcodes" )          => "rotateIn",
									__( "Light Speed In", "adamas-vc-shortcodes" )     => "lightSpeedIn",
									__( "Roll In", "adamas-vc-shortcodes" )            => "rollIn",
								),
								"description" => __( "Like CSS3 Animations? We have several options for you!", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Icon Position", "adamas-vc-shortcodes" ),
								"param_name"  => "icon_position",
								"value"       => array(
									__( 'Top', 'adamas-vc-shortcodes' )            => 'top',
									__( 'Right', 'adamas-vc-shortcodes' )          => 'right',
									__( 'Left', 'adamas-vc-shortcodes' )           => 'left',
									__( 'Behind counter', 'adamas-vc-shortcodes' ) => 'absolute',
								),
								"description" => __( "Enter Position of Icon", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Counter alignment", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_align",
								"value"       => array(
									__( 'Center', 'adamas-vc-shortcodes' ) => 'center',
									__( 'Left', 'adamas-vc-shortcodes' )   => 'left',
									__( 'Right', 'adamas-vc-shortcodes' )  => 'right',
								),
								"description" => __( "Set alignment of counter.", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "checkbox",
								"class"       => "",
								"heading"     => __( "Center alignment", "adamas-vc-shortcodes" ),
								"param_name"  => "center_align",
								"value"       => "",
								"description" => __( "Check this to center align counter inside container.", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Counter Title ", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_title",
								"admin_label" => true,
								"value"       => "",
								"description" => __( "Enter title for stats counter block", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Counter Value", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_value",
								"value"       => "1250",
								"description" => __( "Enter number for counter without any special character. You may enter a decimal number. Eg 12.76", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Thousands Separator", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_sep",
								"value"       => ",",
								"description" => __( "Enter character for thousanda separator. e.g. ',' will separate 125000 into 125,000", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Replace Decimal Point With", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_decimal",
								"value"       => ".",
								"description" => __( "Did you enter a decimal number (Eg - 12.76) The decimal point '.' will be replaced with value that you will enter above.", "adamas-vc-shortcodes" ),
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Counter Value Prefix", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_prefix",
								"value"       => "",
								"description" => __( "Enter prefix for counter value", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Counter Value Suffix", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_suffix",
								"value"       => "",
								"description" => __( "Enter suffix for counter value", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Title padding", "adamas-vc-shortcodes" ),
								"param_name"  => "title_padding",
								"value"       => "",
								"suffix"      => "px",
								"description" => __( "Set padding for title.", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Prefix/Suffix Padding", "adamas-vc-shortcodes" ),
								"param_name"  => "prefix_suffix_padding",
								"value"       => "",
								"suffix"      => "px",
								"description" => __( "Set padding for prefix/suffix.", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Counter rolling time", "adamas-vc-shortcodes" ),
								"param_name"  => "speed",
								"value"       => 3,
								"min"         => 1,
								"max"         => 10,
								"suffix"      => "seconds",
								"description" => __( "How many seconds the counter should roll?", "adamas-vc-shortcodes" )
							),
							//  array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Title Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "font_size_title",
							// 	"value" => 18,
							// 	"min" => 10,
							// 	"max" => 72,
							// 	"suffix" => "px",
							// 	"description" => __("Enter value in pixels.", "adamas-vc-shortcodes")
							// ),
							//  array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Counter Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "font_size_counter",
							// 	"value" => 28,
							// 	"min" => 12,
							// 	"max" => 72,
							// 	"suffix" => "px",
							// 	"description" => __("Enter value in pixels.", "adamas-vc-shortcodes"),
							// ),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Extra Class", "adamas-vc-shortcodes" ),
								"param_name"  => "el_class",
								"value"       => "",
								"description" => __( "Add extra class name that will be applied to the icon process, and you can use this class for your customizations.", "adamas-vc-shortcodes" ),
							),
							// Animation
							array(
								'type'        => 'dropdown',
								'class'       => '',
								'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
								'param_name'  => 'module_animation',
								'value'       => st_adamas_animations_list(),
								'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
							),
							array(
								"type"             => "ult_param_heading",
								"param_name"       => "title_text_typography",
								"heading"          => __( "Counter Title settings", "adamas-vc-shortcodes" ),
								"value"            => "",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper no-top-margin vc_column vc_col-sm-12',
							),
							array(
								"type"       => "ultimate_google_fonts",
								"heading"    => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name" => "title_font",
								"value"      => "",
								"group"      => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "title_font_style",
								"value"      => "",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"param_name" => "title_font_size",
							// 	"heading" => __("Font size","adamas-vc-shortcodes"),
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"min" => 10,
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"param_name" => "title_font_line_height",
							// 	"heading" => __("Font Line Height","adamas-vc-shortcodes"),
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"min" => 10,
							// 	"group" => "Typography"
							// ),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "title_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "title_font_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Color", "adamas-vc-shortcodes" ),
								"param_name"  => "counter_color_txt",
								"value"       => "",
								"description" => __( "Select text color for counter title.", "adamas-vc-shortcodes" ),
								'group'       => "Typography"
							),
							array(
								"type"             => "ult_param_heading",
								"param_name"       => "desc_text_typography",
								"heading"          => __( "Counter Value settings", "adamas-vc-shortcodes" ),
								"value"            => "",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper vc_column vc_col-sm-12',
							),
							array(
								"type"       => "ultimate_google_fonts",
								"heading"    => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name" => "desc_font",
								"value"      => "",
								"group"      => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "desc_font_style",
								"value"      => "",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"param_name" => "desc_font_size",
							// 	"heading" => __("Font size","adamas-vc-shortcodes"),
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"min" => 10,
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"param_name" => "desc_font_line_height",
							// 	"heading" => __("Font Line Height","adamas-vc-shortcodes"),
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"min" => 10,
							// 	"group" => "Typography"
							// ),

							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "desc_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "desc_font_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"        => "colorpicker",
								"param_name"  => "desc_font_color",
								"heading"     => __( "Color", "adamas-vc-shortcodes" ),
								"description" => __( "Select text color for counter digits.", "adamas-vc-shortcodes" ),
								"group"       => "Typography"
							),
							array(
								"type"             => "ult_param_heading",
								"param_name"       => "suf_pref_typography",
								"heading"          => __( "Counter suffix-prefix Value settings", "adamas-vc-shortcodes" ),
								"value"            => "",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper vc_column vc_col-sm-12',
							),
							array(
								"type"       => "ultimate_google_fonts",
								"heading"    => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name" => "suf_pref_font",
								"value"      => "",
								"group"      => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "suf_pref_font_style",
								"value"      => "",
								"group"      => "Typography"
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "suf_pref_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "suf_pref_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"        => "colorpicker",
								"param_name"  => "suf_pref_font_color",
								"heading"     => __( "Color", "adamas-vc-shortcodes" ),
								"description" => __( "Select text color for counter prefix and suffix.", "adamas-vc-shortcodes" ),
								"group"       => "Typography"
							),
							array(
								"type"             => "ult_param_heading",
								"text"             => "<span style='display: block;'><a href='http://bsf.io/t23kn' target='_blank' rel='noopener'>" . __( "Watch Video Tutorial", "adamas-vc-shortcodes" ) . " &nbsp; <span class='dashicons dashicons-video-alt3' style='font-size:30px;vertical-align: middle;color: #e52d27;'></span></a></span>",
								"param_name"       => "notification",
								'edit_field_class' => 'ult-param-important-wrapper ult-dashicon ult-align-right ult-bold-font ult-blue-font vc_column vc_col-sm-12',
							),
							array(
								'type'             => 'css_editor',
								'heading'          => __( 'Css', 'adamas-vc-shortcodes' ),
								'param_name'       => 'css_stat_counter',
								'group'            => __( 'Design ', 'adamas-vc-shortcodes' ),
								'edit_field_class' => 'vc_col-sm-12 vc_column no-vc-background no-vc-border creative_link_css_editor',
							),
							array(
								'type'       => 'colorpicker',
								'heading'    => __( 'Hover background color', 'adamas-vc-shortcodes' ),
								'param_name' => 'bg_color_hover',
								'group'      => __( 'Hover effect', 'adamas-vc-shortcodes' ),
							),
							array(
								'type'       => 'colorpicker',
								'heading'    => __( 'Hover icon color', 'adamas-vc-shortcodes' ),
								'param_name' => 'icon_color_hover',
								'group'      => __( 'Hover effect', 'adamas-vc-shortcodes' ),
							),
							array(
								'type'       => 'colorpicker',
								'heading'    => __( 'Hover icon background color', 'adamas-vc-shortcodes' ),
								'param_name' => 'icon_bg_color_hover',
								'group'      => __( 'Hover effect', 'adamas-vc-shortcodes' ),
							),
							array(
								'type'       => 'colorpicker',
								'heading'    => __( 'Hover counter title color', 'adamas-vc-shortcodes' ),
								'param_name' => 'title_color_hover',
								'group'      => __( 'Hover effect', 'adamas-vc-shortcodes' ),
							),
							array(
								'type'       => 'colorpicker',
								'heading'    => __( 'Hover counter value color', 'adamas-vc-shortcodes' ),
								'param_name' => 'value_color_hover',
								'group'      => __( 'Hover effect', 'adamas-vc-shortcodes' ),
							),
						),
					)
				);
			}
		}

		// Shortcode handler function for stats counter
		function counter_shortcode( $atts ) {
			// enqueue js
			//wp_enqueue_script('ultimate-appear');
			//wp_enqueue_script('ultimate-custom');
			//wp_enqueue_script('front-js',plugins_url('../assets/min-js/countUp.min.js',__FILE__));

			$icon_type      = $icon_img = $img_width = $icon = $icon_color = $icon_color_bg = $icon_size = $icon_style = $icon_border_style = $icon_border_radius = $icon_color_border = $icon_border_size = $icon_border_spacing = $icon_link = $el_class = $icon_animation = $counter_title = $counter_value = $icon_position = $counter_style = $font_size_title = $font_size_counter = $counter_font = $title_font = $speed = $counter_sep = $counter_suffix = $counter_prefix = $counter_decimal = $counter_color_txt = $desc_font_line_height = $title_font_line_height = '';
			$title_font     = $title_font_style = $title_font_size = $title_font_color = $desc_font = $desc_font_style = $desc_font_size = $desc_font_color = $suf_pref_typography = $suf_pref_font = $suf_pref_font_style = $suf_pref_font_color = $suf_pref_font_size = $suf_pref_line_height = '';
			$bg_color_hover = $icon_color_hover = $title_color_hover = $value_color_hover = $icon_bg_color_hover = $prefix_suffix_padding = $title_padding = $counter_align = $animation = $animated = '';
			extract( shortcode_atts( array(
				'icon_type'              => 'selector',
				'icon'                   => '',
				'icon_img'               => '',
				'img_width'              => '48',
				'icon_size'              => '32',
				'icon_color'             => '#333333',
				'icon_style'             => 'none',
				'icon_color_bg'          => '#ffffff',
				'icon_color_border'      => '#333333',
				'icon_border_style'      => '',
				'icon_border_size'       => '1',
				'icon_border_radius'     => '500',
				'icon_border_spacing'    => '50',
				'icon_link'              => '',
				'icon_animation'         => '',
				'counter_title'          => '',
				'counter_value'          => '1250',
				'counter_sep'            => ',',
				'counter_suffix'         => '',
				'counter_prefix'         => '',
				'counter_decimal'        => '.',
				'icon_position'          => 'top',
				'counter_style'          => '',
				'speed'                  => '3',
				'font_size_title'        => '18',
				'font_size_counter'      => '28',
				'counter_color_txt'      => '',
				'title_font'             => '',
				'title_font_style'       => '',
				'title_font_size'        => '',
				'title_font_line_height' => '',
				'desc_font'              => '',
				'desc_font_style'        => '',
				'desc_font_size'         => '',
				'desc_font_color'        => '',
				'desc_font_line_height'  => '',
				'el_class'               => '',
				'suf_pref_font'          => '',
				'suf_pref_font_color'    => '',
				'suf_pref_font_size'     => '',
				'suf_pref_line_height'   => '',
				'suf_pref_font_style'    => '',
				'css_stat_counter'       => '',
				'center_align'           => '',
				'bg_color_hover'         => '',
				'icon_color_hover'       => '',
				'title_color_hover'      => '',
				'value_color_hover'      => '',
				'icon_bg_color_hover'    => '',
				'counter_align'          => '',
				'module_animation'       => '',
				'title_padding'          => '',
				'prefix_suffix_padding'  => '',
			), $atts ) );
			$css_stat_counter = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css_stat_counter, ' ' ), "stat_counter", $atts );
			$css_stat_counter = esc_attr( $css_stat_counter );
			$class            = $style = $title_style = $desc_style = $suf_pref_style = '';
			$hover_style      = '';
			//$font_args = array();
			$stats_icon = do_shortcode( '[just_icon icon_type="' . esc_attr( $icon_type ) . '" icon="' . esc_attr( $icon ) . '" icon_img="' . esc_attr( $icon_img ) . '" img_width="' . esc_attr( $img_width ) . '" icon_size="' . esc_attr( $icon_size ) . '" icon_color="' . esc_attr( $icon_color ) . '" icon_style="' . esc_attr( $icon_style ) . '" icon_color_bg="' . esc_attr( $icon_color_bg ) . '" icon_color_border="' . esc_attr( $icon_color_border ) . '"  icon_border_style="' . esc_attr( $icon_border_style ) . '" icon_border_size="' . esc_attr( $icon_border_size ) . '" icon_border_radius="' . esc_attr( $icon_border_radius ) . '" icon_border_spacing="' . esc_attr( $icon_border_spacing ) . '" icon_link="' . esc_attr( $icon_link ) . '" icon_animation="' . esc_attr( $icon_animation ) . '"]' );

			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . $module_animation . '"';
			}

			if ( $counter_align == '' ) {
				$counter_align = 'center';
			}

			if ( $title_padding !== '' ) {
				if ( is_rtl() ) {
					$title_css = 'style="padding-right:' . $title_padding . 'px;"';
				} else {
					$title_css = 'style="padding-left:' . $title_padding . 'px;"';
				}
			} else {
				$title_css = '';
			}

			if ( $prefix_suffix_padding !== '' ) {
				if ( is_rtl() ) {
					$prefix_padding = 'padding-left:' . $prefix_suffix_padding . 'px;';
					$suffix_padding = 'padding-right:' . $prefix_suffix_padding . 'px;';
				} else {
					$prefix_padding = 'padding-right:' . $prefix_suffix_padding . 'px;';
					$suffix_padding = 'padding-left:' . $prefix_suffix_padding . 'px;';
				}
			} else {
				$prefix_padding = '';
				$suffix_padding = '';
			}

			/* title */
			if ( $title_font != '' ) {
				$font_family = get_ultimate_font_family( $title_font );
				$title_style .= 'font-family:\'' . $font_family . '\';';
				//array_push($font_args, $title_font);
			}
			if ( $title_font_style != '' ) {
				$title_style .= get_ultimate_font_style( $title_font_style );
			}
			// if($title_font_size != '')
			// 	$title_style .= 'font-size:'.$title_font_size.'px;';
			// if($title_font_line_height != '')
			// 	$title_style .= 'line-height:'.$title_font_line_height.'px;';

			//Responsive param
			if ( $title_font_size != '' ) {
				$font_size_title = '';
			}
			if ( is_numeric( $title_font_size ) ) {
				$title_font_size = 'desktop:' . $title_font_size . 'px;';
			}

			if ( is_numeric( $title_font_line_height ) ) {
				$title_font_line_height = 'desktop:' . $title_font_line_height . 'px;';
			}
			$counter_id              = "counter-wrap-" . rand( 1000, 9999 );
			$counter_resp_id         = "counter-responsv-wrap-" . rand( 1000, 9999 );
			$stats_counter_args      = array(
				'target'      => '#' . $counter_resp_id . ' .stats-text', // set targeted element e.g. unique class/id etc.
				'media_sizes' => array(
					'font-size'   => $title_font_size, // set 'css property' & 'ultimate_responsive' sizes. Here $title_responsive_font_size holds responsive font sizes from user input.
					'line-height' => $title_font_line_height
				),
			);
			$stats_counter_data_list = get_ultimate_vc_responsive_media_css( $stats_counter_args );


			/* description */
			if ( $desc_font != '' ) {
				$font_family = get_ultimate_font_family( $desc_font );
				$desc_style  .= 'font-family:\'' . $font_family . '\';';
				//array_push($font_args, $desc_font);
			}
			if ( $desc_font_style != '' ) {
				$desc_style .= get_ultimate_font_style( $desc_font_style );
			}
			// if($desc_font_size != '')
			// 	$desc_style .= 'font-size:'.$desc_font_size.'px;';
			// if($desc_font_line_height != '')
			// 	$desc_style .= 'line-height:'.$desc_font_line_height.'px;';

			//Responsive param
			if ( $desc_font_size != '' || $suf_pref_font_size != '' ) {
				$font_size_counter = '';
			}

			if ( is_numeric( $desc_font_size ) ) {
				$desc_font_size = 'desktop:' . $desc_font_size . 'px;';

			}

			if ( is_numeric( $desc_font_line_height ) ) {
				$desc_font_line_height = 'desktop:' . $desc_font_line_height . 'px;';
			}
			$stats_counter_val_args      = array(
				'target'      => '#' . $counter_resp_id . ' .stats-number', // set targeted element e.g. unique class/id etc.
				'media_sizes' => array(
					'font-size'   => $desc_font_size, // set 'css property' & 'ultimate_responsive' sizes. Here $desc_responsive_font_size holds responsive font sizes from user input.
					'line-height' => $desc_font_line_height
				),
			);
			$stats_counter_val_data_list = get_ultimate_vc_responsive_media_css( $stats_counter_val_args );


			if ( $desc_font_color != '' ) {
				$desc_style .= 'color:' . $desc_font_color . ';';
			}
			//enquque_ultimate_google_fonts($font_args);

			if ( $counter_color_txt !== '' ) {
				$counter_color = 'color:' . $counter_color_txt . ';';
			} else {
				$counter_color = '';
			}
			if ( $icon_color != '' ) {
				$style .= 'color:' . $icon_color . ';';
			}
			if ( $icon_animation !== 'none' ) {
				$css_trans = 'data-animation="' . esc_attr( $icon_animation ) . '" data-animation-delay="03"';
			}
			if ( $font_size_counter !== '' ) {
				$counter_font = 'font-size:' . $font_size_counter . 'px;';
			}

			$title_font = 'font-size:' . $font_size_title . 'px;';

			// Responsive param

			if ( $suf_pref_font != '' ) {
				$font_family    = get_ultimate_font_family( $suf_pref_font );
				$suf_pref_style .= 'font-family:\'' . $font_family . '\';';
				//array_push($font_args, $title_font);
			}
			if ( $suf_pref_font_style != '' ) {
				$suf_pref_style .= get_ultimate_font_style( $suf_pref_font_style );
			}

			// $suf_pref_style .= 'font-size:'.$suf_pref_font_size.'px;';
			// $suf_pref_style .='line-height:'.$suf_pref_line_height.'px;';

			// Responsive param

			if ( is_numeric( $suf_pref_font_size ) ) {
				$suf_pref_font_size = 'desktop:' . $suf_pref_font_size . 'px;';
			}

			if ( is_numeric( $suf_pref_line_height ) ) {
				$suf_pref_line_height = 'desktop:' . $suf_pref_line_height . 'px;';
			}
			$stats_counter_sufpref_args      = array(
				'target'      => '#' . $counter_resp_id . ' .mycust', // set targeted element e.g. unique class/id etc.
				'media_sizes' => array(
					'font-size'   => $suf_pref_font_size, // set 'css property' & 'ultimate_responsive' sizes. Here $desc_responsive_font_size holds responsive font sizes from user input.
					'line-height' => $suf_pref_line_height
				),
			);
			$stats_counter_sufpref_data_list = get_ultimate_vc_responsive_media_css( $stats_counter_sufpref_args );

			$suf_pref_style .= 'color:' . $suf_pref_font_color;


			if ( $counter_style != '' ) {
				$class = $counter_style;
				if ( strpos( $counter_style, 'no_bg' ) ) {
					$style .= "border:2px solid " . $counter_icon_bg_color . ';';
				} elseif ( strpos( $counter_style, 'with_bg' ) ) {
					if ( $counter_icon_bg_color != '' ) {
						$style .= 'background:' . $counter_icon_bg_color . ';';
					}
				}
			}
			if ( $el_class != '' ) {
				$class .= ' ' . $el_class;
			}
			if ( $center_align != '' ) {
				$class .= ' center-align';
			}
			if ( $counter_align != '' ) {
				$class .= ' ' . $counter_align;
			}

			$ic_position = 'stats-' . $icon_position;
			$ic_class    = 'aio-icon-' . $icon_position;
			$output      = '<div class="stats-block ' . esc_attr( $ic_position ) . ' ' . esc_attr( $class ) . ' ' . esc_attr( $css_stat_counter ) . ' ' . $animated . '" id="' . $counter_id . '" ' . $animation . '>';
			//$output .= '<div class="stats-icon" style="'.$style.'">
			//				<i class="'.$stats_icon.'"></i>
			//			</div>';
			$id = 'counter_' . uniqid( rand() );
			if ( $counter_sep == "" ) {
				$counter_sep = 'none';
			}
			if ( $counter_decimal == "" ) {
				$counter_decimal = 'none';
			}
			if ( $icon_position !== "right" ) {
				$output .= '<div class="' . esc_attr( $ic_class ) . '">' . $stats_icon . '</div>';
			}
			$output .= '<div class="stats-desc" id="' . esc_attr( $counter_resp_id ) . '">';
			$output .= '<div class="stats-counter-inner">';
			if ( $counter_prefix !== '' ) {
				$output .= '<div class="counter_prefix mycust ult-responsive" ' . $stats_counter_sufpref_data_list . ' style="' . $prefix_padding . ' ' . esc_attr( $counter_font ) . ' ' . esc_attr( $suf_pref_style ) . '">' . $counter_prefix . '</div>';
			}
			$output .= '<div id="' . esc_attr( $id ) . '" data-id="' . esc_attr( $id ) . '" ' . $stats_counter_val_data_list . ' class="stats-number ult-responsive" style="' . esc_attr( $counter_font ) . ' ' . esc_attr( $counter_color ) . ' ' . esc_attr( $desc_style ) . '" data-speed="' . esc_attr( $speed ) . '" data-counter-value="' . esc_attr( $counter_value ) . '" data-separator="' . esc_attr( $counter_sep ) . '" data-decimal="' . esc_attr( $counter_decimal ) . '">0</div>';
			if ( $counter_suffix !== '' ) {
				$output .= '<div class="counter_suffix mycust ult-responsive" ' . $stats_counter_sufpref_data_list . ' style="' . $suffix_padding . ' ' . esc_attr( $counter_font ) . ' ' . esc_attr( $suf_pref_style ) . '">' . $counter_suffix . '</div>';
			}
			$output .= '</div>';
			$output .= '<div class="stats-text-wrapper" ' . $title_css . '>';
			$output .= '<div id="' . $counter_resp_id . '" ' . $stats_counter_data_list . ' class="stats-text ult-responsive" style="' . esc_attr( $title_font ) . ' ' . esc_attr( $counter_color ) . ' ' . esc_attr( $title_style ) . '">' . $counter_title . '</div>';
			$output .= '</div>'; // stats-text-wrapper
			$output .= '</div>'; // stats-counter-inner
			if ( $icon_position == "right" ) {
				$output .= '<div class="' . esc_attr( $ic_class ) . '">' . $stats_icon . '</div>';
			}
			$output    .= '</div>';
			$is_preset = false; //Display settings for Preset
			if ( isset( $_GET['preset'] ) ) {
				$is_preset = true;
			}
			if ( $is_preset ) {
				$text = 'array ( ';
				foreach ( $atts as $key => $att ) {
					$text .= '<br/>	\'' . $key . '\' => \'' . $att . '\',';
				}
				if ( $content != '' ) {
					$text .= '<br/>	\'content\' => \'' . $content . '\',';
				}
				$text   .= '<br/>)';
				$output .= '<pre>';
				$output .= $text;
				$output .= '</pre>';
			}

			if ( $bg_color_hover != '' || $icon_bg_color_hover != '' || $icon_color_hover != '' || $title_color_hover != '' || $value_color_hover != '' ) {
				$hover_style .= '<style type="text/css">';
				if ( $bg_color_hover != '' ) {
					$hover_style .= '#' . $counter_id . ':hover{background-color:' . $bg_color_hover . '}';
				}
				if ( $icon_bg_color_hover != '' ) {
					$hover_style .= '#' . $counter_id . ':hover .' . $ic_class . ' .ult-just-icon-wrapper .aio-icon{background-color:' . esc_attr( $icon_bg_color_hover ) . ' !important}';
				}
				if ( $icon_color_hover != '' ) {
					$hover_style .= '#' . $counter_id . ':hover .' . $ic_class . ' .ult-just-icon-wrapper .aio-icon{color:' . esc_attr( $icon_color_hover ) . ' !important}';
				}
				if ( $title_color_hover != '' ) {
					$hover_style .= '#' . $counter_id . ':hover .stats-desc .stats-text-wrapper .stats-text{color:' . esc_attr( $title_color_hover ) . ' !important}';
				}
				if ( $value_color_hover != '' ) {
					$hover_style .= '#' . $counter_id . ':hover .stats-desc .stats-counter-inner>div{color:' . esc_attr( $value_color_hover ) . ' !important}';
				}
				$hover_style .= '</style>';
			}

			if ( $hover_style != '' ) {
				$output .= "<script type=\"text/javascript\">jQuery(document).ready(function(){jQuery('head').append('" . $hover_style . "');});</script>";
			}

			return $output;
		}
	}
}
if ( class_exists( 'AIO_Stats_Counter' ) ) {
	$AIO_Stats_Counter = new AIO_Stats_Counter;
}
if ( class_exists( 'WPBakeryShortCode' ) && ! class_exists( 'WPBakeryShortCode_stat_counter' ) ) {
	class WPBakeryShortCode_stat_counter extends WPBakeryShortCode {
	}
}