<?php

class St_Instagram_Feed_Widget extends WP_Widget {
	function __construct() {
		parent::__construct(
			'st_widget_instagram_feed', // Base ID
			'Instagram Feed', // Name
			array( 'description' => __( 'Display Instagram photos.', 'adamas-custom-widgets' ), ) // Args
		);
	}

	function widget( $args, $instance ) {
		extract( $args );
		if ( ! empty( $instance['title'] ) ) {
			$title = apply_filters( 'widget_title', $instance['title'] );
		}

		echo $before_widget;
		if ( ! empty( $title ) ) {
			echo $before_title . $title . $after_title;
		}

		$items = $this->st_get_items( $instance, $instance['image-limit'] );
		$this->st_display_items( $items['items'], $instance );

		echo $after_widget;
	}

	function st_get_items( $instance, $image_limit ) {
		$access_token = $instance['access-token'];
		$response     = wp_remote_get( sprintf( 'https://api.instagram.com/v1/users/self/media/recent/?access_token=%s&count=%s', $access_token, $image_limit ) );

		if ( is_wp_error( $response ) || 200 != wp_remote_retrieve_response_code( $response ) ) {
			return false;
		}

		$data = json_decode( wp_remote_retrieve_body( $response ) );

		$result   = array();
		$username = '';
		foreach ( $data->data as $item ) {

			if ( empty( $username ) ) {
				$username = $item->user->username;
			}

			$result[] = array(
				'link'          => $item->link,
				'image-url'     => $item->images->standard_resolution->url,
				'image-caption' => ! empty( $item->caption->text ) ? $item->caption->text : ''
			);
		}

		$result = array( 'items' => $result, 'username' => $username );

		return $result;
	}

	function st_display_items( $items, $instance ) {
		$count = 0;
		?>
        <ul class="st-instagram-items">
			<?php
			foreach ( $items as $item ) {
				$link = $item['link'];
				$src  = $item['image-url'];
				$alt  = $item['image-caption'];
				?>
                <li>
                    <div class="st-instagram-item">
                        <a href="<?php echo $link; ?>" target="_blank" title="<?php echo $alt; ?>">
                            <div class="st-overlay"></div>
                            <img src="<?php echo $src; ?>" alt="<?php echo $alt; ?>"/>
                        </a>
                    </div>
                </li>
				<?php
				if ( ++ $count === $instance['image-limit'] ) {
					break;
				}

			}
			?>
        </ul>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance['title']        = sanitize_text_field( $new_instance['title'] );
		$instance['image-limit']  = isset( $new_instance['image-limit'] ) ? $new_instance['image-limit'] : '';
		$instance['access-token'] = isset( $new_instance['access-token'] ) ? $new_instance['access-token'] : '';

		return $instance;
	}

	function form( $instance ) {
		$defaults = array( 'title' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );

		$instance['title']        = isset( $instance['title'] ) ? $instance['title'] : '';
		$instance['access-token'] = isset( $instance['access-token'] ) ? $instance['access-token'] : '';
		$instance['image-limit']  = isset( $instance['image-limit'] ) ? $instance['image-limit'] : '';
		?>

        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:', 'adamas-custom-widgets' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>"/>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Access Token:', 'adamas-custom-widgets' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'access-token' ); ?>" name="<?php echo $this->get_field_name( 'access-token' ); ?>" type="text" value="<?php echo esc_attr( $instance['access-token'] ); ?>"/>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id( 'image-limit' ); ?>"><?php esc_html_e( 'Number of Images Shown:', 'adamas-custom-widgets' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'image-limit' ); ?>" name="<?php echo $this->get_field_name( 'image-limit' ); ?>" type="number" min="1" max="20" value="<?php echo esc_attr( $instance['image-limit'] ); ?>"/>
        </p>

		<?php
	}
}

// register	widget
add_action( 'widgets_init', function () {
	register_widget( 'St_Instagram_Feed_Widget' );
} );