<?php

class St_Adamas_Widget_Recent_Reviews extends WC_Widget {

	function __construct() {
		$this->widget_cssclass    = 'woocommerce widget_recent_reviews';
		$this->widget_description = esc_html__( 'Display a list of your most recent reviews on your site.', 'adamas-custom-widgets' );
		$this->widget_id          = 'woocommerce_recent_reviews';
		$this->widget_name        = esc_html__( 'WooCommerce Recent Reviews', 'adamas-custom-widgets' );
		$this->settings           = array(
			'title'  => array(
				'type'  => 'text',
				'std'   => esc_html__( 'Recent Reviews', 'adamas-custom-widgets' ),
				'label' => esc_html__( 'Title', 'adamas-custom-widgets' )
			),
			'number' => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => '',
				'std'   => 10,
				'label' => esc_html__( 'Number of reviews to show', 'adamas-custom-widgets' )
			)
		);

		parent::__construct();
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	function widget( $args, $instance ) {
		global $comments, $comment;

		if ( $this->get_cached_widget( $args ) ) {
			return;
		}

		ob_start();

		$number   = ! empty( $instance['number'] ) ? absint( $instance['number'] ) : $this->settings['number']['std'];
		$comments = get_comments( array(
			'number'      => $number,
			'status'      => 'approve',
			'post_status' => 'publish',
			'post_type'   => 'product'
		) );

		if ( $comments ) {
			$this->widget_start( $args, $instance );

			echo '<ul class="product_list_widget">';

			foreach ( (array) $comments as $comment ) {

				$_product = wc_get_product( $comment->comment_post_ID );

				$rating = intval( get_comment_meta( $comment->comment_ID, 'rating', true ) );

				$rating_html = $_product->get_rating_html( $rating );

				echo '<li><a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '">';

				echo $_product->get_image();

				echo '<span class="product-title">' . $_product->get_title() . '</span></a>';

				printf( '<span class="reviewer">' . esc_html_x( 'by %1$s', 'by comment author', 'adamas-custom-widgets' ) . '</span>', get_comment_author() );

				echo $rating_html;

				echo '</li>';
			}

			echo '</ul>';

			$this->widget_end( $args );
		}

		$content = ob_get_clean();

		echo $content;

		$this->cache_widget( $args, $content );
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Widget_Recent_Reviews' );
} );