<?php
/*
 * Add-on Name: Page Navigation Module
 */
if ( ! class_exists( 'St_Page_Navigation_Module' ) ) {
	class St_Page_Navigation_Module {
		function __construct() {
			add_shortcode( 'st_page_navigation_module', array( $this, 'page_navigation_module_shortcode' ) );
			add_action( 'init', array( $this, 'page_navigation_module_init' ) );
		}

		function page_navigation_module_shortcode( $atts ) {
			$page_nav_data = $page_nav_title = $page_nav_link = $page_nav_link_color = $page_nav_link_color_hover = '';
			$el_class      = $module_animation = $animation = $animated = '';

			extract( shortcode_atts( array(
				'page_nav_link_color'       => '',
				'page_nav_link_color_hover' => '',
				'page_nav_data'             => '',
				'page_nav_title'            => '',
				'page_nav_link'             => '',
				'module_animation'          => '',
				'el_class'                  => '',
			), $atts ) );

			$page_nav_count = 0;
			$output         = '';

			$page_nav_data = json_decode( urldecode( $page_nav_data ), true );
			$id            = 'st-page-navigation-' . random_int( 1000, 9999 );

			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . esc_attr( $module_animation ) . '"';
			}

			$page_nav_link_color_style = '';

			if ( $page_nav_link_color || $page_nav_link_color_hover ) {
				$page_nav_link_color_style .= '<style type="text/css">';

				if ( $page_nav_link_color ) {
					$page_nav_link_color_style .= '#layout-container #' . $id . ' .st-page-navigation-item .st-page-navigation-link span {color: ' . esc_attr( $page_nav_link_color ) . '}';
				}
				if ( $page_nav_link_color_hover ) {
					$page_nav_link_color_style .= '#layout-container #' . $id . ' .st-page-navigation-item .st-page-navigation-link:hover span {color: ' . esc_attr( $page_nav_link_color_hover ) . '}';
				}
				$page_nav_link_color_style .= '</style>';
			}

			$output .= $page_nav_link_color_style;
			$output .= '<div class="st-page-navigation" id="' . $id . '">';
			if ( isset( $page_nav_data ) ) {
				foreach ( $page_nav_data as $page_nav_datas ) {
					$output .= '<div class="st-page-navigation-item ' . $animated . '" ' . $animation . '>';
					if ( $page_nav_datas['page_nav_link'] !== '' ) {
						$page_nav_href = vc_build_link( $page_nav_datas['page_nav_link'] );
						if ( $page_nav_href !== '' ) {
							$page_nav_target = ( $page_nav_href['target'] !== '' ) ? "target='" . esc_attr( trim( $page_nav_href['target'] ) ) . "'" : '';
							$page_nav_title  = ( $page_nav_href['title'] !== '' ) ? "title='" . esc_attr( $page_nav_href['title'] ) . "'" : '';
							if ( ! empty( $page_nav_href['rel'] ) ) {
								$rel = ' rel="' . esc_attr( $page_nav_href['rel'] ) . '"';
							} else {
								$rel = '';
							}

							$output .= '<a class="st-page-navigation-link" href="' . esc_url( $page_nav_href['url'] ) . '" ' . $page_nav_title . ' ' . $page_nav_target . ' ' . $rel . '><i class="st-h-before"><i></i></i><span>' . esc_attr( $page_nav_datas['page_nav_title'] ) . '</span></a>';
						}
					}
					$output .= '</div>'; // st-page-navigation-item
				}
			}
			$output .= '</div>'; // st-page-navigation

			return $output;
		}

		function page_navigation_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Page Navigation', 'adamas-vc-shortcodes' ),
					'base'        => 'st_page_navigation_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/page_navigation.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Displays navigation menu.', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'       => 'param_group',
							'heading'    => __( 'Navigation settings', 'adamas-vc-shortcodes' ),
							'param_name' => 'page_nav_data',
							'value'      => urlencode( json_encode( array(
								array(
									'page_nav_title' => '',
									'page_nav_link'  => '',
								)
							) ) ),
							'params'     => array(
								array(
									'type'        => 'textfield',
									'class'       => '',
									'heading'     => __( 'Title', 'adamas-vc-shortcodes' ),
									'param_name'  => 'page_nav_title',
									'description' => __( 'Set title for navigation element.', 'adamas-vc-shortcodes' ),
									'admin_label' => true
								),
								array(
									'type'        => 'vc_link',
									'class'       => '',
									'param_name'  => 'page_nav_link',
									'heading'     => __( 'Link', 'adamas-vc-shortcodes' ),
									'description' => __( 'Set link for navigation element.', 'adamas-vc-shortcodes' ),
								),
							),
						),
						array(
							'type'        => 'colorpicker',
							'class'       => '',
							'heading'     => __( 'Link color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'page_nav_link_color',
							'description' => __( 'Set color for navigation elements.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'colorpicker',
							'class'       => '',
							'heading'     => __( 'Link color hover', 'adamas-vc-shortcodes' ),
							'param_name'  => 'page_nav_link_color_hover',
							'description' => __( 'Set color for navigation elements on hover.', 'adamas-vc-shortcodes' ),
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_page_navigation_module = new St_Page_Navigation_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_page_navigation_module extends WPBakeryShortCode {
		}
	}
}