<?php
/*
* Add-on Name: Service Box Module
*/
if ( ! class_exists( 'St_Service_Box_Module' ) ) {
	class St_Service_Box_Module {
		function __construct() {
			add_shortcode( 'st_service_box_module', array( $this, 'service_box_module_shortcode' ) );
			add_action( 'init', array( $this, 'service_box_module_init' ) );
		}

		function service_box_module_shortcode( $atts, $content ) {
			$output = $bg_img = $service_box_title = $service_box_subtitle = $service_box_image = $service_box_bg_check = $module_animation = $animation = $animated = $el_class = '';

			extract( shortcode_atts( array(
				'service_box_title'    => '',
				'service_box_subtitle' => '',
				'service_box_bg_check' => '',
				'module_animation'     => '',
				'el_class'             => '',
			), $atts ) );


			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . esc_attr( $module_animation ) . '"';
			}

			if ( $service_box_bg_check ) {
				$el_class .= ' st-service-box-dark-bg';
			}

			$img      = wp_get_attachment_image_src( $atts['service_box_image'], 'full' );
			$img_link = $img[0];

			if ( $img ) {
				$bg_img = ' style="background-image:url(' . esc_url( $img_link ) . ');"';
			}

			$content = wpb_js_remove_wpautop( $content, true );

			$output .= '<div class="st-service-box ' . esc_attr( $el_class ) . '">';
			$output .= '<div class="st-service-box-inner">';
			$output .= '<div class="st-service-box-image" ' . $bg_img . '></div>';
			$output .= '<div class="st-service-box-info ' . esc_attr( $animated ) . '" ' . $animation . '>';
			$output .= '<div class="st-service-box-title"><h3><i class="st-h-before"><i></i><i></i><i></i><i></i></i>' . esc_attr( $service_box_title ) . '</h3></div>';
			$output .= '<div class="st-service-box-subtitle">' . esc_attr( $service_box_subtitle ) . '</div>';
			$output .= '<div class="st-service-box-desc">' . do_shortcode( $content ) . '</div>';
			$output .= '</div>'; // st-single-service-info
			$output .= '</div>'; // st-single-service-inner
			$output .= '</div>'; // st-single-service

			return $output;
		}

		function service_box_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Service Box', 'adamas-vc-shortcodes' ),
					'base'        => 'st_service_box_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/service_box.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Displays service box', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Service title', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_box_title',
							'description' => '',
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Service subtitle', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_box_subtitle',
							'description' => '',
						),
						array(
							'type'        => 'attach_image',
							'heading'     => __( 'Service image', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_box_image',
							'description' => '',
						),
						array(
							'type'        => 'textarea_html',
							'heading'     => __( 'Service box description', 'adamas-vc-shortcodes' ),
							'param_name'  => 'content',
							'description' => '',
						),
						array(
							'type'        => 'checkbox',
							'heading'     => __( 'Background check', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_box_bg_check',
							'description' => __( 'Please, check this if module placed on dark background.', 'adamas-vc-shortcodes' ),
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
					)
				) );
			}
		}
	}

	$st_service_box_module = new St_Service_Box_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_service_box_module extends WPBakeryShortCode {
		}
	}
}