<?php
/*
* Add-on Name: Shop Info Block Module
*/
if ( ! class_exists( 'St_Shop_Info_Block' ) ) {
	class St_Shop_Info_Block {
		function __construct() {
			add_shortcode( 'st_shop_info_block', array( $this, 'shop_info_block_shortcode' ) );
			add_action( 'init', array( $this, 'shop_info_block_init' ) );
		}

		function shop_info_block_shortcode( $atts, $content ) {
			$output    = $title = $bg_color = $icon = $icon_size = $icon_color = $title_font = $title_font_style = $title_color = $title_font_size = $title_line_height = $title_letter_spacing = '';
			$desc_font = $desc_font_style = $desc_color = $desc_font_size = $desc_line_height = $desc_letter_spacing = $el_class = '';

			extract( shortcode_atts( array(
				'title'                => '',
				'bg_color'             => '',
				'icon'                 => '',
				'icon_size'            => '',
				'icon_color'           => '',
				'title_font'           => '',
				'title_font_style'     => '',
				'title_color'          => '',
				'title_font_size'      => '',
				'title_line_height'    => '',
				'title_letter_spacing' => '',
				'desc_font'            => '',
				'desc_font_style'      => '',
				'desc_color'           => '',
				'desc_font_size'       => '',
				'desc_line_height'     => '',
				'desc_letter_spacing'  => '',
				'el_class'             => '',
			), $atts ) );

			$id = uniqid( 'st-shop-info-' );

			$icon_style = '';
			if ( $icon_color !== '' ) {
				$icon_style .= 'color:' . esc_attr( $icon_color ) . ';';
			}
			if ( $icon_size !== '' ) {
				$icon_style .= 'font-size:' . esc_attr( $icon_size ) . 'px; height:' . esc_attr( $icon_size ) . 'px';
			}

			// Title
			$title_style = 'style="';

			if ( $title_font !== '' ) {
				$title_font_family = function_exists( 'get_ultimate_font_family' ) ? get_ultimate_font_family( $title_font ) : '';
				$title_style       .= ! empty( $title_font_family ) ? 'font-family:\'' . $title_font_family . '\';' : '';
			}
			if ( $title_font_style !== '' ) {
				$title_style .= esc_attr( $title_font_style );
			}

			if ( is_numeric( $title_font_size ) ) {
				$title_font_size = 'desktop: ' . $title_font_size . 'px;';
			}
			if ( is_numeric( $title_line_height ) ) {
				$title_line_height = 'desktop: ' . $title_line_height . 'px;';
			}

			$title_args = array(
				'target'      => '#' . $id . ' .st-shop-info-title',
				'media_sizes' => array(
					'font-size'   => $title_font_size,
					'line-height' => $title_line_height,
				),
			);

			$title_responsive = get_ultimate_vc_responsive_media_css( $title_args );
			$title_style      .= $title_letter_spacing !== '' ? 'letter-spacing:' . esc_attr( $title_letter_spacing ) . 'px;' : '';
			$title_style      .= $title_color !== '' ? 'color:' . esc_attr( $title_color ) . ';' : '';
			$title_style      .= '"';

			// Description
			$desc_style = 'style="';

			if ( $desc_font !== '' ) {
				$desc_font_family = function_exists( 'get_ultimate_font_family' ) ? get_ultimate_font_family( $desc_font ) : '';
				$desc_style       .= ! empty( $desc_font_family ) ? 'font-family:\'' . $desc_font_family . '\';' : '';
			}
			if ( $desc_font_style !== '' ) {
				$desc_style .= esc_attr( $desc_font_style );
			}

			if ( is_numeric( $desc_font_size ) ) {
				$desc_font_size = 'desktop: ' . $desc_font_size . 'px;';
			}
			if ( is_numeric( $desc_line_height ) ) {
				$desc_line_height = 'desktop: ' . $desc_line_height . 'px;';
			}

			$desc_args = array(
				'target'      => '#' . $id . ' .st-shop-info-desc',
				'media_sizes' => array(
					'font-size'   => $desc_font_size,
					'line-height' => $desc_line_height,
				),
			);

			$desc_responsive = get_ultimate_vc_responsive_media_css( $desc_args );
			$desc_style      .= $desc_letter_spacing !== '' ? 'letter-spacing:' . esc_attr( $desc_letter_spacing ) . 'px;' : '';
			$desc_style      .= $desc_color !== '' ? 'color:' . esc_attr( $desc_color ) . ';' : '';
			$desc_style      .= '"';

			if ( $bg_color !== '' ) {
				$bg_style = ' style="';
				$bg_style .= $bg_color !== '' ? 'background:' . esc_attr( $bg_color ) . ';' : '';
				$bg_style .= '"';
			} else {
				$bg_style = '';
			}

			$content = wpb_js_remove_wpautop( $content, true );

			$output .= '<div class="st-shop-info-block ' . $el_class . '" id="' . esc_attr( $id ) . '" ' . $bg_style . '>';
			$output .= '<div class="st-shop-info-block-inner">';
			if ( $icon !== '' ) {
				$output .= '<div class="st-shop-info-icon" style="' . $icon_style . '">';
				$output .= '<i class="' . esc_attr( $icon ) . '"></i>';
				$output .= '</div>'; // st-shop-info-icon
			}
			$output .= '<div class="st-shop-info-title-desc-wrapper">';
			$output .= '<div class="st-shop-info-title ult-responsive" ' . $title_style . ' ' . $title_responsive . '><h3>' . esc_attr( $title ) . '</h3></div>';
			$output .= '<div class="st-shop-info-desc ult-responsive" ' . $desc_style . ' ' . $desc_responsive . '>' . do_shortcode( $content ) . '</div>';
			$output .= '</div>'; // st-shop-info-title-desc-wrapper
			$output .= '</div>'; // st-shop-info-block-inner
			$output .= '</div>'; // st-shop-info-block

			return $output;
		}

		function shop_info_block_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'                    => __( 'Shop Info Block', 'adamas-vc-shortcodes' ),
					'base'                    => 'st_shop_info_block',
					'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/shop_info_block.png',
					'category'                => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'show_settings_on_create' => true,
					'params'                  => array(
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Title', 'adamas-vc-shortcodes' ),
							'param_name'  => 'title',
							'description' => '',
							'admin_label' => true,
						),
						array(
							'type'        => 'textarea_html',
							'heading'     => __( 'Description', 'adamas-vc-shortcodes' ),
							'param_name'  => 'content',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Background color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'bg_color',
							'description' => '',
						),
						array(
							'type'        => 'icon_manager',
							'class'       => '',
							'heading'     => __( 'Select Icon', 'adamas-vc-shortcodes' ),
							'param_name'  => 'icon',
							'value'       => '',
							'description' => __( "Click and select icon of your choice. If you can't find the one that suits for your purpose", "adamas-vc-shortcodes" ) . ", " . __( "you can", "adamas-vc-shortcodes" ) . " <a href='admin.php?page=bsf-font-icon-manager' target='_blank'>" . __( "add new here", "adamas-vc-shortcodes" ) . "</a>.",
						),
						array(
							'type'        => 'colorpicker',
							'class'       => '',
							'heading'     => __( 'Icon Color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'icon_color',
							'description' => '',
						),
						array(
							'type'        => 'number',
							'class'       => '',
							'heading'     => __( 'Size of Icon', 'adamas-vc-shortcodes' ),
							'param_name'  => 'icon_size',
							'value'       => 64,
							'min'         => 16,
							'max'         => 300,
							'suffix'      => 'px',
							'description' => __( 'How big would you like it?', 'adamas-vc-shortcodes' ),
						),

						// Title typography
						array(
							'type'        => 'ultimate_google_fonts',
							'heading'     => __( 'Title font family', 'adamas-vc-shortcodes' ),
							'param_name'  => 'title_font',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_google_fonts_style',
							'heading'     => __( 'Title font style', 'adamas-vc-shortcodes' ),
							'param_name'  => 'title_font_style',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Title font color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'title_color',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title font size', 'adamas-vc-shortcodes' ),
							'param_name'  => 'title_font_size',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title line height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'title_line_height',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Title letter spacing', 'adamas-vc-shortcodes' ),
							'param_name'  => 'title_letter_spacing',
							'value'       => '',
							'description' => '',
							'suffix'      => 'px',
							'group'       => 'Typography',
						),

						// Description typography
						array(
							'type'        => 'ultimate_google_fonts',
							'heading'     => __( 'Title font family', 'adamas-vc-shortcodes' ),
							'param_name'  => 'desc_font',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_google_fonts_style',
							'heading'     => __( 'Title font style', 'adamas-vc-shortcodes' ),
							'param_name'  => 'desc_font_style',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Title font color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'desc_color',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title font size', 'adamas-vc-shortcodes' ),
							'param_name'  => 'desc_font_size',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Title line height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'desc_line_height',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Title letter spacing', 'adamas-vc-shortcodes' ),
							'param_name'  => 'desc_letter_spacing',
							'value'       => '',
							'description' => '',
							'suffix'      => 'px',
							'group'       => 'Typography',
						),

						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_shop_info_block = new St_Shop_Info_Block;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_shop_info_block extends WPBakeryShortCode {
		}
	}
}