<?php
/*
* Add-on Name: Single Social Module
*/
if ( ! class_exists( 'St_Single_Social_Block' ) ) {
	class St_Single_Social_Block {
		function __construct() {
			add_shortcode( 'st_single_social_block', array( $this, 'single_social_block_shortcode' ) );
			add_action( 'init', array( $this, 'single_social_block_init' ) );
		}

		function single_social_block_shortcode( $atts, $content ) {
			$output = $icon = $icon_size = $icon_color = $icon_color_hover = $link_output = $bg_color = $hover_style = $bg_color_hover = $el_class = '';

			extract( shortcode_atts( array(
				'icon'             => '',
				'icon_size'        => '',
				'icon_color'       => '',
				'icon_color_hover' => '',
				'bg_color'         => '',
				'bg_color_hover'   => '',
				'link'             => '',
				'el_class'         => '',
			), $atts ) );

			$id = uniqid( 'st-single-social-' );

			if ( $link !== '' ) {
				$link_href = vc_build_link( $link );
				if ( $link_href !== '' ) {
					$link_target = ( $link_href['target'] !== '' ) ? "target='" . esc_attr( trim( $link_href['target'] ) ) . "'" : '';
					$link_title  = ( $link_href['title'] !== '' ) ? "title='" . esc_attr( $link_href['title'] ) . "'" : '';
					if ( ! empty( $link_href['rel'] ) ) {
						$link_rel = ' rel="' . esc_attr( $link_href['rel'] ) . '"';
					} else {
						$link_rel = '';
					}
				}
				$link_before = '<a class="st-single-social-link" href="' . esc_url( $link_href['url'] ) . '" ' . $link_title . ' ' . $link_target . ' ' . $link_rel . '>';
				$link_after  = '</a>';
			} else {
				$link_before = '';
				$link_after  = '';
			}

			$icon_style = '';
			if ( $icon_color !== '' ) {
				$icon_style .= 'color:' . esc_attr( $icon_color ) . ';';
			}
			if ( $icon_size !== '' ) {
				$icon_style .= 'font-size:' . esc_attr( $icon_size ) . 'px; height:' . esc_attr( $icon_size ) . 'px';
			}

			if ( $bg_color !== '' ) {
				$bg_style = ' style="';
				$bg_style .= $bg_color !== '' ? 'background:' . esc_attr( $bg_color ) . ';' : '';
				$bg_style .= '"';
			} else {
				$bg_style = '';
			}

			$content = wpb_js_remove_wpautop( $content, true );

			$output .= '<div class="st-single-social ' . $el_class . '" id="' . $id . '" ' . $bg_style . '>';
			$output .= '<div class="st-single-social-inner">';
			$output .= $link_before;
			if ( $icon !== '' ) {
				$output .= '<div class="st-single-social-icon" style="' . $icon_style . '">';
				$output .= '<i class="' . esc_attr( $icon ) . '"></i>';
				$output .= '</div>'; // st-single-social-icon
			}
			$output .= $link_after;
			$output .= '</div>'; // st-single-social-inner
			$output .= '</div>'; // st-single-social

			if ( $icon_color_hover != '' || $bg_color_hover != '' ) {
				$hover_style .= '<style type="text/css">';
				if ( $icon_color_hover != '' ) {
					$hover_style .= '#' . $id . ':hover .st-single-social-icon{color:' . esc_attr( $icon_color_hover ) . ' !important} ';
				}
				if ( $bg_color_hover != '' ) {
					$hover_style .= '#' . $id . ':hover{background-color:' . esc_attr( $bg_color_hover ) . ' !important}';
				}
				$hover_style .= '</style>';
			}

			if ( $hover_style != '' ) {
				$output .= "<script type=\"text/javascript\">jQuery(document).ready(function(){jQuery('head').append('" . $hover_style . "');});</script>";
			}

			return $output;
		}

		function single_social_block_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'                    => __( 'Single Social Block', 'adamas-vc-shortcodes' ),
					'base'                    => 'st_single_social_block',
					'icon'                    => get_template_directory_uri() . '/assets/images/shortcode_icons/single_social_block.png',
					'category'                => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'show_settings_on_create' => true,
					'params'                  => array(
						array(
							'type'        => 'icon_manager',
							'class'       => '',
							'heading'     => __( 'Select Icon', 'adamas-vc-shortcodes' ),
							'param_name'  => 'icon',
							'value'       => '',
							'description' => __( "Click and select icon of your choice. If you can't find the one that suits for your purpose", "adamas-vc-shortcodes" ) . ", " . __( "you can", "adamas-vc-shortcodes" ) . " <a href='admin.php?page=bsf-font-icon-manager' target='_blank'>" . __( "add new here", "adamas-vc-shortcodes" ) . "</a>.",
						),
						array(
							'type'        => 'number',
							'class'       => '',
							'heading'     => __( 'Size of Icon', 'adamas-vc-shortcodes' ),
							'param_name'  => 'icon_size',
							'value'       => 64,
							'min'         => 16,
							'max'         => 300,
							'suffix'      => 'px',
							'description' => __( 'How big would you like it?', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'vc_link',
							'class'       => '',
							'heading'     => __( 'Link', 'adamas-vc-shortcodes' ),
							'param_name'  => 'link',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'class'       => '',
							'heading'     => __( 'Icon Color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'icon_color',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'class'       => '',
							'heading'     => __( 'Icon Color on hover', 'adamas-vc-shortcodes' ),
							'param_name'  => 'icon_color_hover',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Background color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'bg_color',
							'description' => '',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Background color on hover', 'adamas-vc-shortcodes' ),
							'param_name'  => 'bg_color_hover',
							'description' => '',
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_single_social_block = new St_Single_Social_Block;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_single_social_block extends WPBakeryShortCode {
		}
	}
}