<?php

/**
 * For full documentation, please visit: http://docs.reduxframework.com/
 * For a more extensive sample-config file, you may look at:
 * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
 */

if ( ! class_exists( 'Redux' ) ) {
	return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "adamas";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.
global $st_adamas;
if ( isset( $st_adamas['google_api_key'] ) ) {
	$google_api_key = $st_adamas['google_api_key'];
} else {
	$google_api_key = '';
}

$args = array(
	'opt_name'              => ST_ADAMAS_THEME_NAME,
	'dev_mode'              => false,
	'use_cdn'               => false,
	'display_name'          => $theme->get( 'Name' ),
	'display_version'       => $theme->get( 'Version' ),
	'page_slug'             => '_options',
	'page_title'            => 'Theme Options',
	'admin_bar'             => true,
	'menu_type'             => 'menu',
	'menu_title'            => esc_html__( 'Theme Options', 'adamas' ),
	'allow_sub_menu'        => true,
	'google_api_key'        => $google_api_key,
	'google_update_weekly'  => false,
	'async_typography'      => false,
	'page_parent_post_type' => '',
	'customizer'            => true,
	'hints'                 => array(
		'icon_position' => 'right',
		'icon_size'     => 'normal',
		'tip_style'     => array(
			'color' => 'red',
		),
		'tip_position'  => array(
			'my' => 'top left',
			'at' => 'bottom right',
		),
		'tip_effect'    => array(
			'show' => array(
				'duration' => '500',
				'event'    => 'mouseover',
			),
			'hide' => array(
				'duration' => '500',
				'event'    => 'mouseleave unfocus',
			),
		),
	),
	'output'                => true,
	'output_tag'            => true,
	'settings_api'          => true,
	'cdn_check_time'        => '1440',
	'compiler'              => true,
	'global_variable'       => 'st_' . ST_ADAMAS_THEME_NAME,
	'page_permissions'      => 'manage_options',
	'save_defaults'         => true,
	'show_import_export'    => true,
	'transient_time'        => '3600',
	'network_sites'         => true,
	'show_options_object'   => false,
);

// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
$args['share_icons'][] = array(
	'url'   => 'https://www.facebook.com/SlimTemplate-1887478304798133/',
	'title' => 'Like us on Facebook',
	'icon'  => 'el el-facebook'
);
$args['share_icons'][] = array(
	'url'   => 'https://twitter.com/SlimTemplate',
	'title' => 'Follow us on Twitter',
	'icon'  => 'el el-twitter'
);

Redux::setArgs( $opt_name, $args );

/*
 * ---> END ARGUMENTS
 */

/*
 * ---> START HELP TABS
 */

//

/*
 * <--- END HELP TABS
 */


/*
 *
 * ---> START SECTIONS
 *
 */

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Main', 'adamas' ),
	'id'     => 'main',
	'icon'   => 'el el-home',
	'fields' => array(
		array(
			'id'       => 'boxed_body',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Boxed layout', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to set boxed layout.', 'adamas' ),
			'default'  => '0',
		),
		array(
			'id'       => 'boxed_bg',
			'type'     => 'background',
			'title'    => esc_html__( 'Boxed layout background', 'adamas' ),
			'subtitle' => esc_html__( 'Set boxed layout background.', 'adamas' ),
			'required' => array( 'boxed_body', '=', '1' ),
		),
		array(
			'id'       => 'topbar_enable',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Enable topbar', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to enable topbar.', 'adamas' ),
			'default'  => '1',
		),
		array(
			'id'       => 'smoothscroll_enable',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Enable smoothscroll', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to enable smoothscroll.', 'adamas' ),
			'default'  => '0',
		),
		array(
			'id'       => 'animsition_enable',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Enable preloader', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to enable preloader.', 'adamas' ),
			'default'  => '1',
		),
		array(
			'id'      => 'google_api_key',
			'type'    => 'text',
			'title'   => esc_html__( 'Google API Key', 'adamas' ),
			'desc'    => esc_html__( 'Set your Google API Key.', 'adamas' ),
			'default' => '',
		),
		array(
			'id'       => 'image_404',
			'type'     => 'media',
			'title'    => esc_html__( 'Background for page 404', 'adamas' ),
			'subtitle' => esc_html__( 'Select background image for page 404.', 'adamas' ),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Header', 'adamas' ),
	'id'     => 'header_setup',
	'icon'   => 'el el-caret-up',
	'fields' => array(
		array(
			'id'       => 'header_layout',
			'type'     => 'select',
			'title'    => esc_html__( 'Header Layouts', 'adamas' ),
			'subtitle' => esc_html__( 'Select header layout', 'adamas' ),
			'options'  => st_adamas_header_layouts(),
			'default'  => '1',
		),
		array(
			'id'       => 'header_bg_check',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Header background check', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to set header navigation font color to white and certain logo.', 'adamas' ),
			'default'  => '0',
			'required' => array( 'header_layout', 'equals', array( '3', '4', '5', '7' ) ),
		),
		array(
			'id'       => 'sticky_nav',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Sticky header', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to fix header navigation.', 'adamas' ),
			'default'  => '0',
		),
		array(
			'id'       => 'header_search',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Search', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to display search icon in header.', 'adamas' ),
			'default'  => '1',
		),
		array(
			'id'             => 'header_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'Header font typography', 'adamas' ),
			'google'         => true,
			'subtitle'       => esc_html__( 'Note: font size, weight and style affects only first level of header navigation.', 'adamas' ),
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => false,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'color'          => false,
			'subsets'        => true,
			'preview'        => false,
			'all_styles'     => true,
			'default'        => array(
				'font-size'      => '16',
				'font-weight'    => '700',
				'font-family'    => 'Hind',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
			),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Logos', 'adamas' ),
	'id'     => 'logo_setup',
	'desc'   => esc_html__( 'Logos setup.', 'adamas' ),
	'icon'   => 'el el-picture',
	'fields' => array(
		array(
			'id'       => 'custom_logo',
			'type'     => 'media',
			'title'    => esc_html__( 'Logo image', 'adamas' ),
			'desc'     => esc_html__( 'Upload logo image.', 'adamas' ),
			'subtitle' => esc_html__( 'Recommended height: 60px. Recommended format: PNG', 'adamas' ),
		),
		array(
			'id'       => 'custom_logo_transparent',
			'type'     => 'media',
			'title'    => esc_html__( 'Logo image for transparent header', 'adamas' ),
			'desc'     => esc_html__( 'Upload logo image for transparent header.', 'adamas' ),
			'subtitle' => esc_html__( 'Recommended height: 60px. Recommended format: PNG', 'adamas' ),
		),
		array(
			'id'       => 'custom_logo_light',
			'type'     => 'media',
			'title'    => esc_html__( 'Logo image light', 'adamas' ),
			'desc'     => esc_html__( 'Upload light logo image.', 'adamas' ),
			'subtitle' => esc_html__( 'Recommended height: 60px. Recommended format: PNG', 'adamas' ),
		),
		array(
			'id'       => 'custom_logo_mobile',
			'type'     => 'media',
			'title'    => esc_html__( 'Logo image mobile', 'adamas' ),
			'desc'     => esc_html__( 'Upload mobile logo image.', 'adamas' ),
			'subtitle' => esc_html__( 'Recommended height: px. Recommended format: PNG', 'adamas' ),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Theme colors', 'adamas' ),
	'id'     => 'color_setup',
	'desc'   => esc_html__( 'Color setup.', 'adamas' ),
	'icon'   => 'el el-brush',
	'fields' => array(
		array(
			'id'          => 'main_theme_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Main theme color', 'adamas' ),
			'desc'        => esc_html__( 'Main color of theme.', 'adamas' ),
			'validate'    => 'color',
			'transparent' => false,
			'default'     => '#47588f',
		),
		array(
			'id'          => 'third_theme_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Main theme color first tone', 'adamas' ),
			'desc'        => esc_html__( 'Subfooter background, contact form placeholders color, etc.', 'adamas' ),
			'validate'    => 'color',
			'transparent' => false,
			'default'     => '#3a4876',
		),
		array(
			'id'          => 'fifth_theme_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Main theme color second tone', 'adamas' ),
			'desc'        => esc_html__( 'List markers, contact widget background color, etc.', 'adamas' ),
			'validate'    => 'color',
			'transparent' => false,
			'default'     => '#7e91cc',
		),
		array(
			'id'          => 'second_theme_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Secondary theme color', 'adamas' ),
			'desc'        => esc_html__( 'Accent color for heading markers, contact icons, etc.', 'adamas' ),
			'validate'    => 'color',
			'transparent' => false,
			'default'     => '#f87845',
		),
		array(
			'id'          => 'fourth_theme_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Darken secondary theme color', 'adamas' ),
			'desc'        => esc_html__( 'Secondary color for backgrounds.', 'adamas' ),
			'validate'    => 'color',
			'transparent' => false,
			'default'     => '#f87845',
		),
		array(
			'id'          => 'link_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Link color', 'adamas' ),
			'desc'        => esc_html__( 'Color of links.', 'adamas' ),
			'validate'    => 'color',
			'transparent' => false,
			'default'     => '#47588f',
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Typography', 'adamas' ),
	'id'     => 'typography_setup',
	'icon'   => 'el el-text-height',
	'fields' => array(
		array(
			'id'             => 'main_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'Main Font Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => false,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'color'          => false,
			'subsets'        => true,
			'preview'        => false,
			'all_styles'     => true,
			'default'        => array(
				'font-size'      => '16',
				'font-style'     => '400',
				'font-family'    => 'Hind',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
			),
		),
		array(
			'id'             => 'h1_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'H1 Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => true,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => true,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '50',
				'font-style'     => '700',
				'font-family'    => 'Hind',
				'line-height'    => '64',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
				'color'          => '',
			),
		),
		array(
			'id'             => 'h2_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'H2 Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => true,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => true,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '40',
				'font-style'     => '700',
				'font-family'    => 'Hind',
				'line-height'    => '56',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
			),
		),
		array(
			'id'             => 'h3_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'H3 Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => true,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => true,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '32',
				'font-weight'    => '700',
				'font-family'    => 'Hind',
				'line-height'    => '40',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
			),
		),
		array(
			'id'             => 'h4_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'H4 Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => true,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => true,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '28',
				'font-weight'    => '700',
				'font-family'    => 'Hind',
				'line-height'    => '36',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
			),
		),
		array(
			'id'             => 'h5_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'H5 Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => true,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => true,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '22',
				'font-style'     => '700',
				'font-family'    => 'Hind',
				'line-height'    => '30',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
			),
		),
		array(
			'id'             => 'h6_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'H6 Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'line-height'    => true,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => true,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '20',
				'font-style'     => '800',
				'font-family'    => 'Hind',
				'line-height'    => '24',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
			),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Page Title', 'adamas' ),
	'id'     => 'page_title_setup',
	'desc'   => esc_html__( 'Page title setup.', 'adamas' ),
	'icon'   => 'el el-fontsize',
	'fields' => array(
		array(
			'id'          => 'page_title_overlay',
			'type'        => 'color',
			'title'       => esc_html__( 'Title container overlay color', 'adamas' ),
			'default'     => '#47588f',
			'transparent' => true,
			'validate'    => 'color',
		),
		array(
			'id'             => 'page_title_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'Title Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'line-height'    => true,
			'font-size'      => true,
			'text-align'     => false,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => false,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '40',
				'font-style'     => '700',
				'font-family'    => 'Hind',
				'line-height'    => '56',
				'word-spacing'   => '0',
				'letter-spacing' => '2',
				'text-transform' => 'uppercase',
			),
		),
		array(
			'id'             => 'page_subtitle_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'Subtitle Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-weight'    => true,
			'line-height'    => true,
			'font-size'      => true,
			'text-align'     => false,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => false,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '16',
				'font-style'     => '400',
				'font-family'    => 'Hind',
				'line-height'    => '26',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
			),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Widget Title', 'adamas' ),
	'id'     => 'widget_titles_setup',
	'desc'   => esc_html__( 'Widget titles settings', 'adamas' ),
	'icon'   => 'el el-fontsize',
	'fields' => array(
		array(
			'id'             => 'widget_title_font',
			'type'           => 'typography',
			'title'          => esc_html__( 'Widget Title Typography', 'adamas' ),
			'google'         => true,
			'font-style'     => true,
			'font-size'      => true,
			'text-align'     => false,
			'word-spacing'   => true,
			'letter-spacing' => true,
			'text-transform' => true,
			'color'          => false,
			'preview'        => false,
			'all_styles'     => true,
			'units'          => 'px',
			'default'        => array(
				'font-size'      => '22',
				'font-style'     => '500',
				'font-family'    => 'Hind',
				'line-height'    => '36',
				'word-spacing'   => '0',
				'letter-spacing' => '0',
				'text-transform' => 'none',
			),
		),
		array(
			'id'      => 'widget_title_elem',
			'type'    => 'select',
			'title'   => esc_html__( 'Widget Title Element', 'adamas' ),
			'options' => array(
				'none'          => esc_html__( 'None', 'adamas' ),
				'line-gradient' => esc_html__( 'Line Gradient', 'adamas' ),
				'top'           => esc_html__( 'Top Line', 'adamas' ),
				'side'          => esc_html__( 'Side Line', 'adamas' ),
				'bottom'        => esc_html__( 'Bottom Line', 'adamas' ),
				'square_3'      => esc_html__( 'Square', 'adamas' ),
				'square_2'      => esc_html__( 'Square with empty space inside', 'adamas' ),
				'square'        => esc_html__( 'Square with line', 'adamas' ),
				'circle'        => esc_html__( 'Circle', 'adamas' ),
				'ring'          => esc_html__( 'Ring', 'adamas' ),
			),
			'default' => 'line-gradient',
		),
		array(
			'id'          => 'widget_title_elem_color',
			'type'        => 'color',
			'title'       => esc_html__( 'Widget Title Element Color', 'adamas' ),
			'default'     => '#f87845',
			'validate'    => 'color',
			'transparent' => false,
			'required'    => array( 'widget_title_elem', '!=', 'none' ),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Blog', 'adamas' ),
	'id'     => 'blog_setup',
	'desc'   => esc_html__( 'Posts page settings.', 'adamas' ),
	'icon'   => 'el el-pencil',
	'fields' => array(
		array(
			'id'       => 'blog_layout',
			'type'     => 'select',
			'title'    => esc_html__( 'Blog page width', 'adamas' ),
			'subtitle' => esc_html__( 'Select width for blog page.', 'adamas' ),
			'options'  => array(
				'standard'   => esc_html__( 'Standard', 'adamas' ),
				'full-width' => esc_html__( 'Full width', 'adamas' ),
			),
			'default'  => 'standard',
		),
		array(
			'id'       => 'blog_sidebar',
			'type'     => 'select',
			'title'    => esc_html__( 'Sidebar', 'adamas' ),
			'subtitle' => esc_html__( 'Select sidebar for blog page.', 'adamas' ),
			'options'  => array(
				'no-sidebar' => esc_html__( 'No sidebar', 'adamas' ),
				'right'      => esc_html__( 'Right sidebar', 'adamas' ),
				'left'       => esc_html__( 'Left sidebar', 'adamas' ),
				'both'       => esc_html__( 'Both sidebars', 'adamas' ),
			),
			'default'  => 'right',
		),
		array(
			'id'       => 'blog_page_layout',
			'type'     => 'select',
			'title'    => esc_html__( 'Blog page layout', 'adamas' ),
			'subtitle' => esc_html__( 'Select blog page layout.', 'adamas' ),
			'options'  => array(
				'blog-list' => esc_html__( 'List', 'adamas' ),
				'blog-grid' => esc_html__( 'Grid', 'adamas' ),
			),
			'default'  => 'blog-list',
		),
		array(
			'id'       => 'blog_grid_column_amount',
			'type'     => 'select',
			'title'    => esc_html__( 'Column amount', 'adamas' ),
			'subtitle' => esc_html__( 'Set column amount.', 'adamas' ),
			'required' => array( 'blog_page_layout', '=', 'blog-grid' ),
			'options'  => array(
				'two-column'   => esc_html__( 'Two columns', 'adamas' ),
				'three-column' => esc_html__( 'Three columns', 'adamas' ),
				'four-column'  => esc_html__( 'Four columns', 'adamas' ),
			),
			'default'  => 'two-column',
		),
		array(
			'id'       => 'blog_page_pagination',
			'type'     => 'select',
			'title'    => esc_html__( 'Pagination type', 'adamas' ),
			'subtitle' => esc_html__( 'Set pagination type for blog page.', 'adamas' ),
			'options'  => array(
				'standard' => esc_html__( 'Standard', 'adamas' ),
				'ajax'     => esc_html__( 'Load more', 'adamas' ),
				'lazy'     => esc_html__( 'Lazy load', 'adamas' ),
			),
			'default'  => 'standard',
		),
		array(
			'id'      => 'blog_page_sharing',
			'type'    => 'sorter',
			'title'   => esc_html__( 'Blog page sharing settings', 'adamas' ),
			'options' => array(
				'enabled'  => array(
					'facebook'   => 'Facebook',
					'googleplus' => 'Google Plus',
					'linkedin'   => 'Linked In',
					'pinterest'  => 'Pinterest',
					'twitter'    => 'Twitter',
				),
				'disabled' => array(
					'email'     => 'E-mail',
					'vkontakte' => 'VK',
					'whatsapp'  => 'WhatsApp'
				),
			)
		)
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Projects', 'adamas' ),
	'id'     => 'projects_setup',
	'desc'   => esc_html__( 'Projects settings.', 'adamas' ),
	'icon'   => 'el el-folder-open',
	'fields' => array(
		array(
			'id'    => 'projects_archive',
			'type'  => 'select',
			'title' => esc_html__( 'Projects parent page', 'adamas' ),
			'data'  => 'pages',
			'args'  => array( 'numberposts' => - 1 ),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Archive', 'adamas' ),
	'id'     => 'archive_setup',
	'desc'   => esc_html__( 'Archive page (category, yearly, monthly archive etc) settings.', 'adamas' ),
	'icon'   => 'el el-list',
	'fields' => array(
		array(
			'id'       => 'archive_layout',
			'type'     => 'select',
			'title'    => esc_html__( 'Archive page width', 'adamas' ),
			'subtitle' => esc_html__( 'Select width for archive page.', 'adamas' ),
			'options'  => array(
				'standard'   => esc_html__( 'Standard', 'adamas' ),
				'full-width' => esc_html__( 'Full width', 'adamas' ),
			),
			'default'  => 'standard',
		),
		array(
			'id'       => 'archive_sidebar',
			'type'     => 'select',
			'title'    => esc_html__( 'Sidebar', 'adamas' ),
			'subtitle' => esc_html__( 'Select sidebar for archive page.', 'adamas' ),
			'options'  => array(
				'no-sidebar' => esc_html__( 'No sidebar', 'adamas' ),
				'right'      => esc_html__( 'Right sidebar', 'adamas' ),
				'left'       => esc_html__( 'Left sidebar', 'adamas' ),
				'both'       => esc_html__( 'Both sidebars', 'adamas' ),
			),
			'default'  => 'right',
		),
		array(
			'id'       => 'archive_page_layout',
			'type'     => 'select',
			'title'    => esc_html__( 'Archive page layout', 'adamas' ),
			'subtitle' => esc_html__( 'Select archive page layout.', 'adamas' ),
			'options'  => array(
				'archive-list' => esc_html__( 'List', 'adamas' ),
				'archive-grid' => esc_html__( 'Grid', 'adamas' ),
			),
			'default'  => 'archive-list',
		),
		array(
			'id'       => 'archive_grid_column_amount',
			'type'     => 'select',
			'title'    => esc_html__( 'Column amount', 'adamas' ),
			'subtitle' => esc_html__( 'Set column amount.', 'adamas' ),
			'required' => array( 'archive_page_layout', '=', 'archive-grid' ),
			'options'  => array(
				'two-column'   => esc_html__( 'Two columns', 'adamas' ),
				'three-column' => esc_html__( 'Three columns', 'adamas' ),
				'four-column'  => esc_html__( 'Four columns', 'adamas' ),
			),
			'default'  => 'two-column',
		),
		array(
			'id'       => 'archive_page_pagination',
			'type'     => 'select',
			'title'    => esc_html__( 'Pagination type', 'adamas' ),
			'subtitle' => esc_html__( 'Set pagination type for archive page.', 'adamas' ),
			'options'  => array(
				'standard' => esc_html__( 'Standard', 'adamas' ),
				'ajax'     => esc_html__( 'Load more', 'adamas' ),
				'lazy'     => esc_html__( 'Lazy load', 'adamas' ),
			),
			'default'  => 'standard',
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Single post', 'adamas' ),
	'id'     => 'single_post_setup',
	'desc'   => esc_html__( 'Single post page settings.', 'adamas' ),
	'icon'   => 'el el-file-edit',
	'fields' => array(
		array(
			'id'       => 'single_post_width',
			'type'     => 'select',
			'title'    => esc_html__( 'Single post page width', 'adamas' ),
			'subtitle' => esc_html__( 'Set page width for single post:<br>standard - 1200px;<br>full-width - full screen width.', 'adamas' ),
			'options'  => array(
				'standard'   => esc_html__( 'Standard', 'adamas' ),
				'full-width' => esc_html__( 'Full width', 'adamas' ),
			),
			'default'  => 'standard',
		),
		array(
			'id'       => 'single_post_sidebar',
			'type'     => 'select',
			'title'    => esc_html__( 'Single post page sidebar', 'adamas' ),
			'subtitle' => esc_html__( 'Set sidebars for single post.', 'adamas' ),
			'options'  => array(
				'none'  => esc_html__( 'None', 'adamas' ),
				'left'  => esc_html__( 'Left sidebar', 'adamas' ),
				'right' => esc_html__( 'Right sidebar', 'adamas' ),
				'both'  => esc_html__( 'Both sidebars', 'adamas' ),
			),
			'default'  => 'right',
		),
		array(
			'id'      => 'mailchimp_shortcode',
			'type'    => 'text',
			'title'   => esc_html__( 'MailChimp subscribing form shortcode', 'adamas' ),
			'desc'    => esc_html__( 'Set shortcode for MC form.', 'adamas' ),
			'default' => '',
		),
		array(
			'id'      => 'single_post_sharing',
			'type'    => 'sorter',
			'title'   => esc_html__( 'Single post sharing settings', 'adamas' ),
			'options' => array(
				'enabled'  => array(
					'facebook'   => 'Facebook',
					'googleplus' => 'Google Plus',
					'linkedin'   => 'Linked In',
					'pinterest'  => 'Pinterest',
					'twitter'    => 'Twitter',
				),
				'disabled' => array(
					'email'     => 'E-mail',
					'vkontakte' => 'VK',
					'whatsapp'  => 'WhatsApp'
				),
			)
		)
	)
) );

if ( class_exists( 'woocommerce' ) ) {
	Redux::setSection( $opt_name, array(
		'title'  => esc_html__( 'Shop', 'adamas' ),
		'id'     => 'Shop_setup',
		'desc'   => esc_html__( 'Shop (products) page settings.', 'adamas' ),
		'icon'   => 'el el-shopping-cart',
		'fields' => array(
			array(
				'id'       => 'shop_products_amount',
				'type'     => 'text',
				'title'    => esc_html__( 'Products show at most', 'adamas' ),
				'subtitle' => esc_html__( 'Set amount of products per page.', 'adamas' ),
				'validate' => 'numeric',
				'default'  => '3',
			),
			array(
				'id'       => 'shop_layout',
				'type'     => 'select',
				'title'    => esc_html__( 'Shop layout', 'adamas' ),
				'subtitle' => esc_html__( 'Select layout for shop page.', 'adamas' ),
				'options'  => array(
					'standard'   => esc_html__( 'Standard', 'adamas' ),
					'full-width' => esc_html__( 'Full width', 'adamas' ),
				),
				'default'  => 'standard',
			),
			array(
				'id'       => 'shop_sidebar',
				'type'     => 'select',
				'title'    => esc_html__( 'Sidebar', 'adamas' ),
				'subtitle' => esc_html__( 'Select sidebar for shop page.', 'adamas' ),
				'options'  => array(
					'none'  => esc_html__( 'No sidebar', 'adamas' ),
					'right' => esc_html__( 'Right sidebar', 'adamas' ),
					'left'  => esc_html__( 'Left sidebar', 'adamas' ),
					'both'  => esc_html__( 'Both sidebars', 'adamas' ),
				),
				'default'  => 'left',
			),
			array(
				'id'       => 'shop_column_amount',
				'type'     => 'select',
				'title'    => esc_html__( 'Column amount', 'adamas' ),
				'subtitle' => esc_html__( 'Set column amount.', 'adamas' ),
				'options'  => array(
					2 => esc_html__( 'Two columns', 'adamas' ),
					3 => esc_html__( 'Three columns', 'adamas' ),
					4 => esc_html__( 'Four columns', 'adamas' ),
				),
				'default'  => 3,
			),
			array(
				'id'       => 'shop_page_pagination',
				'type'     => 'select',
				'title'    => esc_html__( 'Pagination type', 'adamas' ),
				'subtitle' => esc_html__( 'Set pagination type for shop page.', 'adamas' ),
				'options'  => array(
					'standard' => esc_html__( 'Standard', 'adamas' ),
					'ajax'     => esc_html__( 'Load more', 'adamas' ),
					'lazy'     => esc_html__( 'Lazy load', 'adamas' ),
				),
				'default'  => 'standard',
			),
			array(
				'id'       => 'shop_page_hover_effect',
				'type'     => 'checkbox',
				'title'    => esc_html__( 'Disable hover effect', 'adamas' ),
				'subtitle' => esc_html__( 'Check this to disable displaying second product image on hover.', 'adamas' ),
				'default'  => '1',
			),
		)
	) );

	Redux::setSection( $opt_name, array(
		'title'  => esc_html__( 'Single product', 'adamas' ),
		'id'     => 'single_product_setup',
		'desc'   => esc_html__( 'Single product page settings.', 'adamas' ),
		'icon'   => 'el el-tag',
		'fields' => array(
			array(
				'id'       => 'single_product_width',
				'type'     => 'select',
				'title'    => esc_html__( 'Single product page width', 'adamas' ),
				'subtitle' => esc_html__( 'Set page width for single product:<br>- standard - 1200px;<br>- full-width - full screen width.', 'adamas' ),
				'options'  => array(
					'standard'   => esc_html__( 'Standard', 'adamas' ),
					'full-width' => esc_html__( 'Full width', 'adamas' ),
				),
				'default'  => 'standard',
			),
			array(
				'id'       => 'single_product_sidebar',
				'type'     => 'select',
				'title'    => esc_html__( 'Single product page sidebar', 'adamas' ),
				'subtitle' => esc_html__( 'Set sidebars for single product.', 'adamas' ),
				'options'  => array(
					'none'  => esc_html__( 'None', 'adamas' ),
					'left'  => esc_html__( 'Left sidebar', 'adamas' ),
					'right' => esc_html__( 'Right sidebar', 'adamas' ),
					'both'  => esc_html__( 'Both sidebars', 'adamas' ),
				),
				'default'  => 'right',
			),
			array(
				'id'      => 'single_product_sharing',
				'type'    => 'sorter',
				'title'   => esc_html__( 'Single product sharing settings', 'adamas' ),
				'options' => array(
					'enabled'  => array(
						'facebook'   => 'Facebook',
						'googleplus' => 'Google Plus',
						'linkedin'   => 'Linked In',
						'pinterest'  => 'Pinterest',
						'twitter'    => 'Twitter',
					),
					'disabled' => array(
						'email'     => 'E-mail',
						'vkontakte' => 'VK',
						'whatsapp'  => 'WhatsApp'
					),
				)
			)
		)
	) );
}

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Socials', 'adamas' ),
	'id'     => 'socials_setup',
	'desc'   => esc_html__( 'Socials setup.', 'adamas' ),
	'icon'   => 'el el-link',
	'fields' => array(
		array(
			'id'    => 'socials_facebook',
			'type'  => 'text',
			'title' => esc_html__( 'Facebook', 'adamas' ),
			'desc'  => esc_html__( 'Set link to Facebook account.', 'adamas' ),
		),
		array(
			'id'    => 'socials_twitter',
			'type'  => 'text',
			'title' => esc_html__( 'Twitter', 'adamas' ),
			'desc'  => esc_html__( 'Set link to Twitter account.', 'adamas' ),
		),
		array(
			'id'    => 'socials_instagram',
			'type'  => 'text',
			'title' => esc_html__( 'Instagram', 'adamas' ),
			'desc'  => esc_html__( 'Set link to Instagram account.', 'adamas' ),
		),
		array(
			'id'    => 'socials_gplus',
			'type'  => 'text',
			'title' => esc_html__( 'Google Plus', 'adamas' ),
			'desc'  => esc_html__( 'Set link to Google Plus account.', 'adamas' ),
		),
		array(
			'id'    => 'socials_linkedin',
			'type'  => 'text',
			'title' => esc_html__( 'Linked In', 'adamas' ),
			'desc'  => esc_html__( 'Set link to Linked In account.', 'adamas' ),
		),
		array(
			'id'    => 'socials_pinterest',
			'type'  => 'text',
			'title' => esc_html__( 'Pinterest', 'adamas' ),
			'desc'  => esc_html__( 'Set link to Pinterest account.', 'adamas' ),
		),
		array(
			'id'    => 'socials_youtube',
			'type'  => 'text',
			'title' => esc_html__( 'YouTube', 'adamas' ),
			'desc'  => esc_html__( 'Set link to YouTube account.', 'adamas' ),
		),
		array(
			'id'    => 'socials_vk',
			'type'  => 'text',
			'title' => esc_html__( 'VK', 'adamas' ),
			'desc'  => esc_html__( 'Set link to VK account.', 'adamas' ),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Topbar contacts', 'adamas' ),
	'id'     => 'topbar_setup',
	'desc'   => esc_html__( 'Topbar contacts setup.', 'adamas' ),
	'icon'   => 'el el-phone',
	'fields' => array(
		array(
			'id'         => 'contact_department',
			'type'       => 'multi_text',
			'title'      => esc_html__( 'Department', 'adamas' ),
			'desc'       => esc_html__( 'Department name.', 'adamas' ),
			'show_empty' => false,
		),
		array(
			'id'         => 'contact_address',
			'type'       => 'multi_text',
			'title'      => esc_html__( 'Address', 'adamas' ),
			'desc'       => esc_html__( 'Department address.', 'adamas' ),
			'show_empty' => false,
		),
		array(
			'id'         => 'contact_phone',
			'type'       => 'multi_text',
			'title'      => esc_html__( 'Phone number', 'adamas' ),
			'desc'       => esc_html__( 'Department phone number.', 'adamas' ),
			'show_empty' => false,
		),
		array(
			'id'         => 'contact_schedule',
			'type'       => 'multi_text',
			'title'      => esc_html__( 'Schedule', 'adamas' ),
			'desc'       => esc_html__( 'Department schedule.', 'adamas' ),
			'show_empty' => false,
		),
		array(
			'id'         => 'contact_email',
			'type'       => 'multi_text',
			'title'      => esc_html__( 'Email', 'adamas' ),
			'desc'       => esc_html__( 'Department email.', 'adamas' ),
			'show_empty' => false,
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Footer', 'adamas' ),
	'id'     => 'footer_setup',
	'icon'   => 'el el-website',
	'fields' => array(
		array(
			'id'       => 'footer',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Enable footer area', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to enable footer widget area.', 'adamas' ),
			'default'  => '1',
		),
		array(
			'id'       => 'footer_columns_layout',
			'type'     => 'select',
			'title'    => esc_html__( 'Footer columns layout', 'adamas' ),
			'desc'     => esc_html__( 'Set amount of footer columns.', 'adamas' ),
			'options'  => array(
				'6' => esc_html__( 'Two columns', 'adamas' ),
				'4' => esc_html__( 'Three columns', 'adamas' ),
				'3' => esc_html__( 'Four columns', 'adamas' ),
			),
			'default'  => '3',
			'required' => array( 'footer', '=', '1' ),
		),
		array(
			'id'       => 'footer_columns_custom_width',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Custom width for footer columns', 'adamas' ),
			'subtitle' => esc_html__( 'Check this to set custom width for footer columns.', 'adamas' ),
			'default'  => '0',
			'required' => array( 'footer', '=', '1' ),
		),
		array(
			'id'       => 'footer_first_column_width',
			'type'     => 'select',
			'title'    => esc_html__( 'First column width', 'adamas' ),
			'subtitle' => esc_html__( 'Select width of first footer column.', 'adamas' ),
			'desc'     => esc_html__( 'Column width accroding to bootstrap.', 'adamas' ),
			'options'  => array(
				'1'  => esc_html__( 'One column', 'adamas' ),
				'2'  => esc_html__( 'Two columns', 'adamas' ),
				'3'  => esc_html__( 'Three columns', 'adamas' ),
				'4'  => esc_html__( 'Four columns', 'adamas' ),
				'5'  => esc_html__( 'Five columns', 'adamas' ),
				'6'  => esc_html__( 'Six columns', 'adamas' ),
				'7'  => esc_html__( 'Seven columns', 'adamas' ),
				'8'  => esc_html__( 'Eight columns', 'adamas' ),
				'9'  => esc_html__( 'Nine columns', 'adamas' ),
				'10' => esc_html__( 'Ten columns', 'adamas' ),
				'11' => esc_html__( 'Eleven columns', 'adamas' ),
				'12' => esc_html__( 'Twelve columns', 'adamas' ),
			),
			'default'  => '4',
			'required' => array(
				array( 'footer', '=', '1' ),
				array( 'footer_columns_layout', '=', array( '6', '4', '3' ) ),
				array( 'footer_columns_custom_width', '=', '1' ),
			),
		),
		array(
			'id'       => 'footer_second_column_width',
			'type'     => 'select',
			'title'    => esc_html__( 'Second column width', 'adamas' ),
			'subtitle' => esc_html__( 'Select width of second footer column.', 'adamas' ),
			'desc'     => esc_html__( 'Column width accroding to bootstrap.', 'adamas' ),
			'options'  => array(
				'1'  => esc_html__( 'One column', 'adamas' ),
				'2'  => esc_html__( 'Two columns', 'adamas' ),
				'3'  => esc_html__( 'Three columns', 'adamas' ),
				'4'  => esc_html__( 'Four columns', 'adamas' ),
				'5'  => esc_html__( 'Five columns', 'adamas' ),
				'6'  => esc_html__( 'Six columns', 'adamas' ),
				'7'  => esc_html__( 'Seven columns', 'adamas' ),
				'8'  => esc_html__( 'Eight columns', 'adamas' ),
				'9'  => esc_html__( 'Nine columns', 'adamas' ),
				'10' => esc_html__( 'Ten columns', 'adamas' ),
				'11' => esc_html__( 'Eleven columns', 'adamas' ),
				'12' => esc_html__( 'Twelve columns', 'adamas' ),
			),
			'default'  => '4',
			'required' => array(
				array( 'footer', '=', '1' ),
				array( 'footer_columns_layout', '=', array( '6', '4', '3' ) ),
				array( 'footer_columns_custom_width', '=', '1' ),
			),
		),
		array(
			'id'       => 'footer_third_column_width',
			'type'     => 'select',
			'title'    => esc_html__( 'Third column width', 'adamas' ),
			'subtitle' => esc_html__( 'Select width of third footer column.', 'adamas' ),
			'desc'     => esc_html__( 'Column width accroding to bootstrap.', 'adamas' ),
			'options'  => array(
				'1'  => esc_html__( 'One column', 'adamas' ),
				'2'  => esc_html__( 'Two columns', 'adamas' ),
				'3'  => esc_html__( 'Three columns', 'adamas' ),
				'4'  => esc_html__( 'Four columns', 'adamas' ),
				'5'  => esc_html__( 'Five columns', 'adamas' ),
				'6'  => esc_html__( 'Six columns', 'adamas' ),
				'7'  => esc_html__( 'Seven columns', 'adamas' ),
				'8'  => esc_html__( 'Eight columns', 'adamas' ),
				'9'  => esc_html__( 'Nine columns', 'adamas' ),
				'10' => esc_html__( 'Ten columns', 'adamas' ),
				'11' => esc_html__( 'Eleven columns', 'adamas' ),
				'12' => esc_html__( 'Twelve columns', 'adamas' ),
			),
			'default'  => '4',
			'required' => array(
				array( 'footer', '=', '1' ),
				array( 'footer_columns_layout', '=', array( '4', '3' ) ),
				array( 'footer_columns_custom_width', '=', '1' ),
			),
		),
		array(
			'id'       => 'footer_fourth_column_width',
			'type'     => 'select',
			'title'    => esc_html__( 'Fourth column width', 'adamas' ),
			'subtitle' => esc_html__( 'Select width of fourth footer column.', 'adamas' ),
			'desc'     => esc_html__( 'Column width accroding to bootstrap.', 'adamas' ),
			'options'  => array(
				'1'  => esc_html__( 'One column', 'adamas' ),
				'2'  => esc_html__( 'Two columns', 'adamas' ),
				'3'  => esc_html__( 'Three columns', 'adamas' ),
				'4'  => esc_html__( 'Four columns', 'adamas' ),
				'5'  => esc_html__( 'Five columns', 'adamas' ),
				'6'  => esc_html__( 'Six columns', 'adamas' ),
				'7'  => esc_html__( 'Seven columns', 'adamas' ),
				'8'  => esc_html__( 'Eight columns', 'adamas' ),
				'9'  => esc_html__( 'Nine columns', 'adamas' ),
				'10' => esc_html__( 'Ten columns', 'adamas' ),
				'11' => esc_html__( 'Eleven columns', 'adamas' ),
				'12' => esc_html__( 'Twelve columns', 'adamas' ),
			),
			'default'  => '4',
			'required' => array(
				array( 'footer', '=', '1' ),
				array( 'footer_columns_layout', '=', '3' ),
				array( 'footer_columns_custom_width', '=', '1' ),
			),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Subfooter', 'adamas' ),
	'id'     => 'subfooter_setup',
	'icon'   => 'el el-caret-down',
	'fields' => array(
		array(
			'id'    => 'subfooter_about_text',
			'type'  => 'textarea',
			'title' => esc_html__( 'Subfooter About Text', 'adamas' ),
			'desc'  => esc_html__( 'Subfooter text about', 'adamas' ),
		),
		array(
			'id'    => 'subfooter_copyright_text',
			'type'  => 'textarea',
			'title' => esc_html__( 'Subfooter Copyright Text', 'adamas' ),
			'desc'  => esc_html__( 'Subfooter copyright about', 'adamas' ),
		),
		array(
			'id'    => 'first_link',
			'type'  => 'text',
			'title' => esc_html__( 'Subfooter link 1', 'adamas' ),
			'desc'  => '',
		),
		array(
			'id'    => 'first_link_title',
			'type'  => 'text',
			'title' => esc_html__( 'Subfooter link 1 title', 'adamas' ),
			'desc'  => '',
		),
		array(
			'id'    => 'second_link',
			'type'  => 'text',
			'title' => esc_html__( 'Subfooter link 2', 'adamas' ),
			'desc'  => '',
		),
		array(
			'id'    => 'second_link_title',
			'type'  => 'text',
			'title' => esc_html__( 'Subfooter link 2 title', 'adamas' ),
			'desc'  => '',
		),
		array(
			'id'    => 'third_link',
			'type'  => 'text',
			'title' => esc_html__( 'Subfooter link 3', 'adamas' ),
			'desc'  => '',
		),
		array(
			'id'    => 'third_link_title',
			'type'  => 'text',
			'title' => esc_html__( 'Subfooter link 3 title', 'adamas' ),
			'desc'  => '',
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Custom CSS and JS', 'adamas' ),
	'id'     => 'custom_css_js',
	'icon'   => 'el el-magic',
	'fields' => array(
		array(
			'id'    => 'custom_css',
			'type'  => 'ace_editor',
			'title' => esc_html__( 'Custom CSS', 'adamas' ),
			'desc'  => esc_html__( 'Add here custom CSS code.', 'adamas' ),
			'mode'  => 'css',
		),
		array(
			'id'    => 'custom_js',
			'type'  => 'ace_editor',
			'title' => esc_html__( 'Custom JS', 'adamas' ),
			'desc'  => esc_html__( 'Add here custom JS code.', 'adamas' ),
			'mode'  => 'javascript',
		),
	)
) );
/*
 * <--- END SECTIONS
 */

// Header Layouts Array
function st_adamas_header_layouts() {
	return array(
		'1' => esc_html__( 'Header Layout 1', 'adamas' ),
		'2' => esc_html__( 'Header Layout 2', 'adamas' ),
		'3' => esc_html__( 'Header Layout 3', 'adamas' ),
		'4' => esc_html__( 'Header Layout 4', 'adamas' ),
		'5' => esc_html__( 'Header Layout 5', 'adamas' ),
		'6' => esc_html__( 'Header Layout 6', 'adamas' ),
		'7' => esc_html__( 'Header Layout 7', 'adamas' ),
	);
}