<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme Adamas for publication on WordPress.org
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

require_once get_template_directory() . '/includes/lib/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'st_adamas_register_required_plugins' );

/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function st_adamas_register_required_plugins() {

	$plugins = array(

		array(
			'name'               => 'Visual Composer',
			'slug'               => 'js_composer',
			'source'             => get_template_directory() . '/plugins/js_composer.zip',
			'required'           => true,
			'version'            => '5.7',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'               => 'Slider Revolution',
			'slug'               => 'revslider',
			'source'             => get_template_directory() . '/plugins/revslider.zip',
			'required'           => false,
			'version'            => '5.4.8.3',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'               => 'Ultimate VC Addons',
			'slug'               => 'Ultimate_VC_Addons',
			'source'             => get_template_directory() . '/plugins/Ultimate_VC_Addons.zip',
			'required'           => true,
			'version'            => '3.18.0',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'               => 'Adamas Custom Post Types and Taxonomies',
			'slug'               => 'adamas-cpt',
			'source'             => get_template_directory() . '/plugins/adamas-cpt.zip',
			'required'           => true,
			'version'            => '1.0.0',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'               => 'Adamas Custom Widgets',
			'slug'               => 'adamas-custom-widgets',
			'source'             => get_template_directory() . '/plugins/adamas-custom-widgets.zip',
			'required'           => true,
			'version'            => '1.0.1',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'               => 'Adamas VC Shortcodes',
			'slug'               => 'adamas-vc-shortcodes',
			'source'             => get_template_directory() . '/plugins/adamas-vc-shortcodes.zip',
			'required'           => true,
			'version'            => '1.0',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'               => 'Adamas Demo Import',
			'slug'               => 'adamas-demo-importer',
			'source'             => get_template_directory() . '/plugins/adamas-demo-importer.zip',
			'required'           => true,
			'version'            => '1.0',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'               => 'Advanced Custom Fields PRO',
			'slug'               => 'advanced-custom-fields-pro',
			'source'             => get_template_directory() . '/plugins/advanced-custom-fields-pro.zip',
			'required'           => false,
			'version'            => '5.7.13',
			'force_activation'   => false,
			'force_deactivation' => false,
		),

		array(
			'name'     => 'Contact Form 7',
			'slug'     => 'contact-form-7',
			'required' => false,
		),

		array(
			'name'     => 'MailChimp for WordPress',
			'slug'     => 'mailchimp-for-wp',
			'required' => false,
		),

		array(
			'name'     => 'TinyMCE Advanced',
			'slug'     => 'tinymce-advanced',
			'required' => false,
		),

	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'adamas',
		'default_path' => '',
		'menu'         => 'tgmpa-install-plugins',
		'has_notices'  => true,
		'dismissable'  => true,
		'dismiss_msg'  => '',
		'is_automatic' => true,
		'message'      => '',
	);

	tgmpa( $plugins, $config );
}
